******************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 6: GENERATING AN ASSET INDEX FOR URBAN HOUSEHOLDS
*
* Based on T. Pave Sohnesen's do-file
* Created: April 25, 2013
* Modified by: Sebastian Monroy
* Last updated: May 21, 2014
******************************************************************************************************

/* 
This do-file generates an asset index for each of the following countries:
	- Armenia
	- Georgia
	- Ghana
	- Macedonia
	- Kenya
	
	*/


global pathworkingdata


************************************************************* Armenia *************************************************************
use "$pathworkingdata/STEP Armenia_working.dta", clear

keep if elegido==1 & urban==1 & age>14

* GENERATE VARIABLES
*  Dwelling Characteristics

* Type
gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)

factor d_* [aw=W_FinSPwt], mineigen(1)
alpha d_*, item detail
sum d_*


* Wall
gen w_concrete=(m1b_q02==5)
gen w_brick=(m1b_q02==1)
gen w_wood=(m1b_q02==7)
gen w_adobe=(m1b_q02==2)
gen w_stone=(m1b_q02==3)
gen w_tin=(m1b_q02==8)

factor w_* [aw=W_FinSPwt], mineigen(1)
alpha w_*, item detail
sum w_*



* Roof
gen r_slate=(m1b_q03==1)
gen r_metal=(m1b_q03==2)
gen r_concrete=(m1b_q03==4)
gen r_tile=(m1b_q03==5)
 
factor r_* [aw=W_FinSPwt], mineigen(1)
alpha r_*, item detail
sum r_*


* Floor 
gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_carpet=(m1b_q04==6)

factor f_* [aw=W_FinSPwt], mineigen(1)
alpha f_*, item detail
sum f_*


* Ownership
gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

factor o_* [aw=W_FinSPwt], mineigen(1)
alpha o_*, item detail
sum o_*

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

factor room_* [aw=W_FinSPwt], mineigen(1)
alpha room_*, item detail
sum room_*

    
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_opipe=(m1b_q08==3)
gen dw_well=(m1b_q08==4|m1b_q08==5)
gen dw_truc=(m1b_q08==8)
gen dw_bottle=(m1b_q08==9)

factor dw_* [aw=W_FinSPwt], mineigen(1)
alpha dw_*, item detail
sum dw_*

*cooking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_build=(m1b_q10==3)
gen c_out=(m1b_q10==4)
gen c_not=(m1b_q10==5)

gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_gas=(m1b_q11==3)
gen c_bio=(m1b_q11==4)
gen c_coal=(m1b_q11==5|m1b_q11==7)

factor c_* [aw=W_FinSPwt], mineigen(1)
alpha c_*, item detail
sum c_*


*lightning
gen l_privat=(m1b_q12==2)
gen l_coop=(m1b_q12==3)
gen l_pub=(m1b_q12==1)

factor l_* [aw=W_FinSPwt], mineigen(1)
alpha l_*, item detail
sum l_*

*toilet
gen to_flush=(m1b_q13>=1 & m1b_q13<=4)
gen to_pit=(m1b_q13==5|m1b_q13==6|m1b_q13==7)

gen to_shared=(m1b_q14==1)

factor to_* [aw=W_FinSPwt], mineigen(1)
alpha to_*, item detail
sum to_*

*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1 | m1b_q15_7==1)
gen a_airc=(m1b_q15_8 ==1)
gen a_comp=(m1b_q15_9 ==1)
gen a_int=(m1b_q15_10==1)
gen a_bicy=(m1b_q15_11==1)
gen a_motorc=(m1b_q15_12==1)
gen a_three=(m1b_q15_13==1)
gen a_car=(m1b_q15_14==1)
gen a_waterh=(m1b_q15_15==1)
gen a_animal=(m1b_q15_16==1)
gen a_boat=(m1b_q15_17==1|m1b_q15_18==1)
gen a_camera=(m1b_q15_19==1|m1b_q15_20==1)

factor a_* [aw=W_FinSPwt], mineigen(1)
alpha a_*, item detail
sum a_*

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

factor a2_* [aw=W_FinSPwt], mineigen(1)
alpha a2_*, item detail
sum a2_*

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_hors=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pigs=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)

factor ag_* [aw=W_FinSPwt], mineigen(1)
alpha ag_*, item detail
sum ag_*

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 gen book_fw=(m1b_q18==5)
 gen book_mn=(m1b_q18==6)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  c_* to_* ag_* room_* dw_* l_*
 
* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_cell1 a_tv a_motorc a_three a_animal a_boat a2_other d_indiv r_tile ///
	 f_earth w_brick w_wood w_adobe w_tin c_build c_out c_not c_bio c_coal ///
	 to_flush to_pit ag_cow ag_hors ag_pigs ag_goat ag_sheep room_6up dw_opipe ///
	 dw_well dw_truc dw_bottle l_privat l_coop l_pub

*Overview of all assets 
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* ag_* dw_* ag_*  [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_*  c_* to_* ag_* dw_* 
/*Comments: All asset have loading factors as could be expected, 13 egen values are above 1 and the first one explain 15.45%.
Cronbach's alpha at  0.7444 indicate a moderate underlying measure*/

**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_*  to_* dw_* [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_*  to_* dw_* 
/*Dwelling has 10 egen values are above 1 and the first one only explain 17.48%.
Cronbach's Alpha at  0.7035 indicate a moderate underlying measure*/

*Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*
/*Assets1 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 93.27 % of variation, Cronbach's alpha at  0.7361 indicate
a strong underleying measure*/
 
*Assests 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/* no factors retained*/
*rotate, varimax
factor a2_* [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.4188 indicating low underlying measure */



*Agriculture
*factor ag_* [aw=W_FinSPwt], mineigen(1)
/*Not enough agricultural variables*/
*rotate, varimax
*predict agri
*alpha ag_*


 
pwcorr all_assets dwelling asset1 asset2 [aw=W_FinSPwt], sig
/* asset seem not to correlate well with overall asset index */


*Dropping agriculture related
drop a2_agri a2_poul ag_*

*Dropping assets not relates to overall assets (<0.1 of factor loading, before rotation): 
drop a_radio a_refri a_airc a_bicy a_car 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
drop a2_sech a2_ins
 
*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop f_tile f_carpet o_free room_1 c_kitch c_house c_elec c_lpg c_gas to_shared dw_pipe


***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_* o_* room_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_* o_* room_* 
/* Cronbach's Alpha: 0.7515.*/

*kdensity asset_index [aw=W_FinSPwt], bw(0.3)
xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)

label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

drop d_house-asset2

compress 
save "$pathworkingdata/STEP Armenia_working.dta", replace

************************************************************* Ghana *************************************************************
use "$pathworkingdata/STEP Ghana_working.dta", clear
keep if elegido==1 & urban==1 & age>14

* GENERATE VARIABLES
*  Dwelling Characteristics

* Type
gen d_house=(m1b_q01==1|m1b_q01==2)
gen d_apart=(m1b_q01==3)
gen d_comp1=(m1b_q01==4)
gen d_comp2=(m1b_q01==5)
gen d_huts=(m1b_q01==6)
gen d_temp=(m1b_q01==7)

factor d_* [aw=W_FinSPwt], mineigen(1)
alpha d_*, item detail
sum d_*

* Wall
gen w_concrete=(m1b_q02==8)
gen w_brick=(m1b_q02==4)
gen w_wood=(m1b_q02==2)
gen w_adobe=(m1b_q02==5)
gen w_stone=(m1b_q02==3 | m1b_q02==9)
gen w_earth=(m1b_q02==1)
gen w_metal=(m1b_q02==10)
gen w_palm=(m1b_q02==7 | m1b_q02==6)

factor w_* [aw=W_FinSPwt], mineigen(1)
alpha w_*, item detail
sum w_*

* Roof
gen r_slate=(m1b_q03==4)
gen r_metal=(m1b_q03==3)
gen r_concrete=(m1b_q03==5)
gen r_tile=(m1b_q03==9)
gen r_mbrick=(m1b_q03==1)
gen r_wood=(m1b_q03==2)
gen r_palm=(m1b_q03==7|m1b_q03==8)
gen r_card=(m1b_q03==6)

factor r_* [aw=W_FinSPwt], mineigen(1)
alpha r_*, item detail
sum r_*

* Floor 
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==6)
gen f_tile=(m1b_q04==7)
gen f_earth=(m1b_q04==1)
gen f_palm=(m1b_q04==3)
gen f_ceramic=(m1b_q04==5)
gen f_brick=(m1b_q04==8)
gen f_vinyl=(m1b_q04==4)

factor f_* [aw=W_FinSPwt], mineigen(1)
alpha f_*, item detail
sum f_*

* Ownership
gen o_own=(m1b_q05==1)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

factor o_* [aw=W_FinSPwt], mineigen(1)
alpha o_*, item detail
sum o_*

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

factor room_* [aw=W_FinSPwt], mineigen(1)
alpha room_*, item detail
sum room_*

    
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_opipe=(m1b_q08==3|m1b_q08==4|m1b_q08==5)
gen dw_well=(m1b_q08==6|m1b_q08==7|m1b_q08==8)
gen dw_sprin=(m1b_q08==10|m1b_q08==14|m1b_q08==15)
gen dw_rain=(m1b_q08==11)
gen dw_truc=(m1b_q08==12|m1b_q08==13)
gen dw_bottle=(m1b_q08==16|m1b_q08==17)

factor dw_* [aw=W_FinSPwt], mineigen(1)
alpha dw_*, item detail
sum dw_*

*cooking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2|m1b_q10==4)
gen c_build=(m1b_q10==3)
gen c_out=(m1b_q10==5)
gen c_not=(m1b_q10==6)

gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_gas=(m1b_q11==3)
gen c_bio=(m1b_q11==4)
gen c_coal=(m1b_q11==5|m1b_q11==7)
gen c_kero=(m1b_q11==6)
gen c_agr=(m1b_q11==9)


factor c_* [aw=W_FinSPwt], mineigen(1)
alpha c_*, item detail
sum c_*

*lightning
gen l_elec=(m1b_q12==1)
gen l_gen=(m1b_q12==2)
gen l_lamp=(m1b_q12==4|m1b_q12==5)
gen l_wood=(m1b_q12==7)
gen l_flash=(m1b_q12==9)
gen l_none=(m1b_q12==10)

factor l_* [aw=W_FinSPwt], mineigen(1)
alpha l_*, item detail
sum l_*

*toilet

*toilet
gen to_flush=(m1b_q13==1)
gen to_pit=(m1b_q13==2|m1b_q13==3)
gen to_bucket=(m1b_q13==4)
gen to_public=(m1b_q13==5)
gen to_noth=(m1b_q13==6)
gen to_none=(m1b_q13==7)

gen to_shared1=(m1b_q14==1|m1b_q14==2|m1b_q14==3)

factor to_* [aw=W_FinSPwt], mineigen(1)
alpha to_*, item detail
sum to_*

*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_animal=(m1b_q15_15==1)
gen a_boat=(m1b_q15_16==1|m1b_q15_17==1)
gen a_swe=(m1b_q15_18==1)
gen a_stove=(m1b_q15_19==1)
gen a_camera=(m1b_q15_20==1| m1b_q15_21==1)
gen a_iron=(m1b_q15_22==1| m1b_q15_23==1)

factor a_* [aw=W_FinSPwt], mineigen(1)
alpha a_*, item detail
sum a_*

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

factor a2_* [aw=W_FinSPwt], mineigen(1)
alpha a2_*, item detail
sum a2_*

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_hors=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pigs=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)

factor ag_* [aw=W_FinSPwt], mineigen(1)
alpha ag_*, item detail
sum ag_*

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 gen book_fw=(m1b_q18==5)
 gen book_mn=(m1b_q18==6)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  c_* to_* ag_* room_* dw_* l_*
 
* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_animal a_boat d_huts r_tile r_mbrick r_wood r_palm f_wood f_palm f_brick f_vinyl w_bric w_adobe w_stone ///
	 w_metal w_palm c_elec c_gas c_bio c_kero c_agr to_bucket to_noth ag_cow ag_hors ag_pig dw_sprin ///
	 dw_rain dw_truc l_gen l_lamp l_wood l_none
	 

*Overview of all assets 
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* ag_* dw_* l_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_*  c_* to_* ag_* dw_* 
/*Comments: All asset have loading factors as could be expected, 19 egen values are above 1 and the first one explain 16.70%.
Cronbach's alpha at  0.8433 indicate a strong underlying measure*/

**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_*  to_* dw_* l_* [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_*  to_* dw_* l_*
/*Dwelling has 17 egen values are above 1 and the first one only explain 12.07%.
Cronbach's Alpha at  0.7360 indicate a moderate underlying measure*/

*Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*
/*Assets1 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 85.62 % of variation, Cronbach's alpha at  0.7708 indicate
a strong underleying measure*/
 
*Assests 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/* no factors retained*/
*rotate,varimax
factor a2_*   [aw=W_FinSPwt]
predict asset2
alpha a2_*
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1, 
an index was estimated with all the variables. Cronbach's alpha is 0.4516 indicating low underlying measure */

* Agriculture
factor ag_* [aw=W_FinSPwt], mineigen(1)
/* no factors retained*/
*rotate, varimax
factor ag_* [aw=W_FinSPwt]
predict agri
alpha ag_*
/*Aagri do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1, 
an index was estimated with all the variables. Cronbach's alpha is 0.5108 indicating weak underlying measure */

pwcorr all_assets dwelling asset1 asset2 agri [aw=W_FinSPwt], sig
/* Agriculture has low correlation with the overall index */

*Dropping agriculture related
drop a2_agri a2_poul ag_*

*Dropping assets not relates to overall assets (<0.1 of factor loading): 
drop a_bicy a_motorc a_three 

*Dropping secondary assets that not relates to overall assets (<0.1 of factor loading):
/*none*/

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading):
drop d_comp2 r_card o_own o_rent room_2 room_3 c_build c_not to_pit 


***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* dw_* l_*  [aw=W_FinSPwt], mineigen(1) 
predict asset_index 
alpha  a_* a2_* d_* r_* f_* w_* o_* room_* c_* dw_* l_*
/* Cronbach's Alpha: 0.8592*/

*kdensity asset_index [aw=W_FinSPwt]
xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)

label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

drop d_house-agri
compress
save "$pathworkingdata/STEP Ghana_working.dta", replace

************************************************************* Georgia *************************************************************
use "$pathworkingdata/STEP Georgia_working.dta", clear
keep if elegido==1 & urban==1 & age>14
rename W3_FinSPwt W_FinSPwt

* GENERATE VARIABLES
*  Dwelling Characteristics

* Type
gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)
gen d_temp=(m1b_q01==5)

factor d_* [aw=W_FinSPwt], mineigen(1)
alpha d_*, item detail
sum d_*

* Wall
gen w_concrete=(m1b_q02==5)
gen w_brick=(m1b_q02==1)
gen w_wood=(m1b_q02==7)
gen w_adobe=(m1b_q02==2)
gen w_stone=(m1b_q02==3)
gen w_earth=(m1b_q02==4)

factor w_* [aw=W_FinSPwt], mineigen(1)
alpha w_*, item detail
sum w_*

* Roof
gen r_slate=(m1b_q03==1)
gen r_metal=(m1b_q03==2)
gen r_concrete=(m1b_q03==4)
gen r_tile=(m1b_q03==5)

factor r_* [aw= W_FinSPwt], mineigen(1)
alpha r_*, item detail
sum r_*

* Floor 
gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_carpet=(m1b_q04==6)

factor f_* [aw=W_FinSPwt], mineigen(1)
alpha f_*, item detail
sum f_*


* Ownership
gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

factor o_* [aw=W_FinSPwt], mineigen(1)
alpha o_*, item detail
sum o_*

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

factor room_* [aw=W_FinSPwt], mineigen(1)
alpha room_*, item detail
sum room_*

    
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_opipe=(m1b_q08==3)
gen dw_well=(m1b_q08==4)
gen dw_sprin=(m1b_q08==5|m1b_q08==6)
gen dw_bottle=(m1b_q08==9)

factor dw_* [aw=W_FinSPwt], mineigen(1)
alpha dw_*, item detail
sum dw_*

*cooking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_build=(m1b_q10==3)
gen c_out=(m1b_q10==4)

gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_gas=(m1b_q11==3)
gen c_bio=(m1b_q11==4)
gen c_coal=(m1b_q11==5|m1b_q11==7)

factor c_* [aw=W_FinSPwt], mineigen(1)
alpha c_*, item detail
sum c_*

*lightning
gen l_privat=(m1b_q12==2)
gen l_coop=(m1b_q12==3)
gen l_pub=(m1b_q12==1)

factor l_* [aw=W_FinSPwt], mineigen(1)
alpha l_*, item detail
sum l_*

*toilet

*toilet
gen to_flush=(m1b_q13>=1 & m1b_q13<=4)
gen to_pit=(m1b_q13==5|m1b_q13==6|m1b_q13==7)
gen to_bucket=(m1b_q13==9|m1b_q12==10)
gen to_shared=(m1b_q14==1)

factor to_* [aw=W_FinSPwt], mineigen(1)
alpha to_*, item detail
sum to_*

*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4 ==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_waterh=(m1b_q15_14==1)
gen a_animal=(m1b_q15_15==1)
gen a_boat=(m1b_q15_16==1|m1b_q15_17==1)
gen a_dvd=(m1b_q15_18==1)
gen a_camera=(m1b_q15_19==1)

factor a_* [aw=W_FinSPwt], mineigen(1)
alpha a_*, item detail
sum a_*

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

factor a2_* [aw=W_FinSPwt], mineigen(1)
alpha a2_*, item detail
sum a2_*

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_hors=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pigs=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)

factor ag_* [aw=W_FinSPwt], mineigen(1)
alpha ag_*, item detail
sum ag_*

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 gen book_fw=(m1b_q18==5)
 gen book_mn=(m1b_q18==6)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  c_* to_* ag_* room_* dw_* l_*
 
* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_motorc a_three a_animal a_boat d_temp f_tile f_earth w_wood c_build c_out c_bio to_bucket ///
	 ag_hors ag_goat ag_sheep dw_opipe dw_well dw_sprin dw_bottle l_privat l_coop l_pub

*Overview of all assets 
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* ag_* dw_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_*  c_* to_* ag_* dw_* 
/*Comments: All asset have loading factors as could be expected, 13 egen values are above 1 and the first one explain 18.21%.
Cronbach's alpha at  0.8130 indicate a moderate underlying measure*/

**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_*  to_* dw_* [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_*  to_* dw_* 
/*Dwelling has 11 egen values are above 1 and the first one only explain 18.66%.
Cronbach's Alpha at  0.7748 indicate a moderate underlying measure*/

*Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*
/*Assets1 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 88.17 % of variation, Cronbach's alpha at  0.7885 indicate
a strong underleying measure*/
 
*Assests 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
rotate,varimax
predict asset2
alpha a2_*
/*Assets2 do seem to represent underlying definition of wealth with 1 egenvalues over 1 and the first one explais 114% of variation, 
and Cronbach's Alpha is low at 0.5690*/

* Agriculture
factor ag_* [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict agri
alpha ag_*
/* Agriculture has 1 egen value above 1 and it explains 147% of the variation. The Cronbach's alpha is low 0.5729*/ 

pwcorr all_assets dwelling asset1 asset2 agri [aw=W_FinSPwt], sig
/* All seem correlated well */

*Dropping agriculture related
drop a2_agri a2_poul ag_*

*Dropping assets not relates to overall assets (<0.1 of factor loading): 
drop a_radio a_bicy a_dvd 

*Dropping secondary assets that not relates to overall assets (<0.1 of factor loading):
drop a2_bank a2_ins

*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading):
drop f_concrete f_carpet w_adobe w_earth o_own o_rent room_1 room_4 c_elec


***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_*  [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_* o_* room_* c_* 
/* Cronbach's Alpha: 0.8063.*/

*kdensity asset_index [aw=W_FinSPwt]
xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)

label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"

drop d_house-agri
compress
save "$pathworkingdata/STEP Georgia_working.dta", replace


************************************************************* Macedonia *************************************************************
use "$pathworkingdata/STEP Macedonia_working.dta", clear
keep if elegido==1 & urban==1 & age>14
svyset cluster [pw=W_FinSPwt]

* GENERATE VARIABLES
*  Dwelling Characteristics

* Type
gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)

factor d_* [aw=W_FinSPwt], mineigen(1)
alpha d_*, item detail
sum d_*


* Wall
gen w_concrete=(m1b_q02==4)
gen w_brick=(m1b_q02==1)
gen w_wood=(m1b_q02==6)
gen w_adobe=(m1b_q02==2|m1b_q02==5|m1b_q02==8)
gen w_stone=(m1b_q02==3)
gen w_tin=(m1b_q02==7)

factor w_* [aw=W_FinSPwt], mineigen(1)
alpha w_*, item detail
sum w_*


* Roof
gen r_metal=(m1b_q03==1)
gen r_concrete=(m1b_q03==2)
gen r_tile=(m1b_q03==3 | m1b_q03==6)
gen r_tin=(m1b_q03==4)
gen r_batten=(m1b_q03==5)

 
factor r_* [aw=W_FinSPwt], mineigen(1)
alpha r_*, item detail
sum r_*


* Floor 
gen f_parquet=(m1b_q04==1)
gen f_wood=(m1b_q04==2)
gen f_concrete=(m1b_q04==3)
gen f_tile=(m1b_q04==4)
gen f_earth=(m1b_q04==5)
gen f_carpet=(m1b_q04==6)
gen f_marble=(m1b_q04==7)

factor f_* [aw=W_FinSPwt], mineigen(1)
alpha f_*, item detail
sum f_*


* Ownership
gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

factor o_* [aw=W_FinSPwt], mineigen(1)
alpha o_*, item detail
sum o_*

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

factor room_* [aw=W_FinSPwt], mineigen(1)
alpha room_*, item detail
sum room_*

    
*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2|m1b_q08==3)
gen dw_opipe=(m1b_q08==4|m1b_q08==5|m1b_q08==7)
gen dw_well=(m1b_q08==4|m1b_q08==9|m1b_q08==10)
gen dw_bottle=(m1b_q08==14)

factor dw_* [aw=W_FinSPwt], mineigen(1)
alpha dw_*, item detail
sum dw_*

*cooking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_build=(m1b_q10==3)
gen c_out=(m1b_q10==4)
gen c_not=(m1b_q10==5)

gen c_elec=(m1b_q11==1)
gen c_gas=(m1b_q11==2)
gen c_coal=(m1b_q11==3|m1b_q11==4)

factor c_* [aw=W_FinSPwt], mineigen(1)
alpha c_*, item detail
sum c_*


*lightning
gen l_house=(m1b_q12==2)
gen l_cande=(m1b_q12==9)
gen l_pub=(m1b_q12==1)

factor l_* [aw=W_FinSPwt], mineigen(1)
alpha l_*, item detail
sum l_*

*toilet
gen to_flush=(m1b_q13>=1 & m1b_q13<=2)|m1b_q13==5
gen to_pit=(m1b_q13==3|m1b_q13==4|m1b_q13==6)

gen to_shared=(m1b_q14==1)

factor to_* [aw=W_FinSPwt], mineigen(1)
alpha to_*, item detail
sum to_*

*assets
gen a_cell1=(m1b_q15_01 ==1)
gen a_phone=(m1b_q15_02 ==1)
gen a_radio=(m1b_q15_03 ==1)
gen a_tv=(m1b_q15_04==1)
gen a_refri=(m1b_q15_05 ==1)
gen a_wash=(m1b_q15_06 ==1)
gen a_airc=(m1b_q15_07 ==1)
gen a_comp=(m1b_q15_08 ==1)
gen a_int=(m1b_q15_09==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1|m1b_q15_13==1)
gen a_car=(m1b_q15_14==1)
gen a_animal=(m1b_q15_15==1)
gen a_boat=(m1b_q15_16==1|m1b_q15_17==1)
gen a_waterh=(m1b_q15_18==1)
gen a_microw=(m1b_q15_19==1)
gen a_dish=(m1b_q15_20==1)
gen a_vacuum=(m1b_q15_21==1)
gen a_dvd=(m1b_q15_22==1)
gen a_camera=(m1b_q15_23==1)

factor a_* [aw=W_FinSPwt], mineigen(1)
alpha a_*, item detail
sum a_*

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

factor a2_* [aw=W_FinSPwt], mineigen(1)
alpha a2_*, item detail
sum a2_*

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_hors=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_pigs=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_3 >0 & m1b_q17_3 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)
gen ag_rabbits=(m1b_q17_7 >0 & m1b_q17_7 ~=.)
gen ag_bees=(m1b_q17_8 >0 & m1b_q17_8 ~=.)



factor ag_* [aw=W_FinSPwt], mineigen(1)
alpha ag_*, item detail
sum ag_*

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 gen book_fw=(m1b_q18==5)
 gen book_mn=(m1b_q18==6)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  c_* to_* ag_* room_* dw_* l_*
 
* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_cell1 a_tv a_refri a_three a_animal a_boat r_batten ///
	 f_tile f_earth f_marble w_wood w_stone w_tin c_build c_out c_not ///
	 to_flush to_pit ag_cow ag_hors ag_pigs ag_goat ag_sheep ag_chick ///
	 ag_rabbits ag_bees room_1 dw_pipe dw_opipe dw_well dw_bottle ///
	 l_house l_cande l_pub
	 
	 
*Overview of all assets 
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_*  c_* to_*
/*Comments: All asset have loading factors as could be expected, 13 egen values are above 1 and the first one explain 16.75%.
Cronbach's alpha at  0.7899 indicate a moderate underlying measure*/

**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* to_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_* to_*  
/*Dwelling has 12 egen values are above 1 and the first one only explain 13.47%.
Cronbach's Alpha at  0.7334 indicate a moderate underlying measure*/

*Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*
/*Assets1 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 82.66 % of variation, Cronbach's alpha at  0.7957 indicate
a strong underleying measure*/
 
*Assests 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
/* no factors retained*/
*rotate, varimax
/*Assets2 do not jointly seem to represent underlying definition of wealth with 0 egenvalues over 1 
an index was estimated with all the variables. Cronbach's alpha is 0.4213 indicating low underlying measure */



*Agriculture
*factor ag_* [aw=W_FinSPwt], mineigen(1)
/*Not enough agricultural variables*/
*rotate, varimax
*predict agri
*alpha ag_*


 
pwcorr all_assets dwelling asset1 [aw=W_FinSPwt], sig
/* asset seem to correlate well with overall asset index */

preserve
*Dropping agriculture related
drop a2_agri a2_poul 

*Dropping assets not related to overall assets (<0.1 of factor loading, before rotation): 
drop a_motorc 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
drop a2_ins a2_other 
 
*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_indiv o_own o_free o_rent room_2 room_4 room_5 to_shared


***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_*  room_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_*  room_* 
/* Cronbach's Alpha: 0.7988.*/

kdensity asset_index [aw=W_FinSPwt], nodraw

* Asset_q quintiles 
xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5) 

keep asset_q country asset_index hhn cluster idcode W_FinSPwt
sort cluster hhn idcode
save "$pathworkingdata/Temp.dta", replace
restore

clear all
u "$pathworkingdata/STEP Macedonia_working.dta", replace
keep if elegido==1 & urban==1 & age>14
sort cluster hhn idcode

merge cluster hhn idcode using "$pathworkingdata/Temp.dta"
tab _merge
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"
compress
sort cluster hhn idcode
save "$pathworkingdata/STEP Macedonia_working.dta", replace


************************************************************* Kenya *************************************************************
use "$pathworkingdata/STEP Kenya_working.dta", clear
keep if elegido==1 & urban==1 & age>14
svyset cluster [pw=W_FinSPwt]


* GENERATE VARIABLES
*  Dwelling Characteristics

* Type
gen d_house=(m1b_q01==1)
gen d_indiv=(m1b_q01==2)
gen d_apart=(m1b_q01==3|m1b_q01==4)
gen d_temp=(m1b_q01==5)

factor d_* [aw=W_FinSPwt], mineigen(1)
alpha d_*, item detail
sum d_*


* Wall
gen w_concrete=(m1b_q02==4)
gen w_brick=(m1b_q02==2)
gen w_wood=(m1b_q02==5)
gen w_adobe=(m1b_q02==3|m1b_q02==7)
gen w_stone=(m1b_q02==1)
gen w_tin=(m1b_q02==6|m1b_q02==8)

factor w_* [aw=W_FinSPwt], mineigen(1)
alpha w_*, item detail
sum w_*


* Roof
gen r_metal=(m1b_q03==1)
gen r_concrete=(m1b_q03==3)
gen r_tile=(m1b_q03==2)
gen r_asbestos=(m1b_q03==4)
gen r_grass=(m1b_q03==5 | m1b_q03==6)
gen r_tin=(m1b_q03==7)
 
factor r_* [aw=W_FinSPwt], mineigen(1)
alpha r_*, item detail
sum r_*


* Floor 
gen f_wood=(m1b_q04==3)
gen f_concrete=(m1b_q04==1)
gen f_tile=(m1b_q04==2)
gen f_earth=(m1b_q04==4)

factor f_* [aw=W_FinSPwt], mineigen(1)
alpha f_*, item detail
sum f_*


* Ownership
gen o_own=(m1b_q05==1|m1b_q05==2)
gen o_free=(m1b_q05==3|m1b_q05==4|m1b_q05==5)
gen o_rent=(m1b_q05==6)

factor o_* [aw=W_FinSPwt], mineigen(1)
alpha o_*, item detail
sum o_*

*number of rooms
gen room_1=(m1b_q06==1)
gen room_2=(m1b_q06==2)
gen room_3=(m1b_q06==3)
gen room_4=(m1b_q06==4)
gen room_5=(m1b_q06==5)
gen room_6up=(m1b_q06>=6&m1b_q06~=.)

factor room_* [aw=W_FinSPwt], mineigen(1)
alpha room_*, item detail
sum room_*

*drinking water
gen dw_pipe=(m1b_q08==1|m1b_q08==2)
gen dw_opipe=(m1b_q08==3|m1b_q08==10)
gen dw_well=(m1b_q08==4|m1b_q08==5)
gen dw_spring=(m1b_q08==6|m1b_q08==7|m1b_q08==8)
gen dw_rain=(m1b_q08==9)
gen dw_bottle=(m1b_q08==12)

factor dw_* [aw=W_FinSPwt], mineigen(1)
alpha dw_*, item detail
sum dw_*

*cooking
gen c_kitch=(m1b_q10==1)
gen c_house=(m1b_q10==2)
gen c_build=(m1b_q10==3)
gen c_out=(m1b_q10==4)
gen c_not=(m1b_q10==5)

gen c_elec=(m1b_q11==1)
gen c_lpg=(m1b_q11==2)
gen c_para=(m1b_q11==3)
gen c_bio=(m1b_q11==4)
gen c_coal=(m1b_q11==5|m1b_q11==6)

factor c_* [aw=W_FinSPwt], mineigen(1)
alpha c_*, item detail
sum c_*

*lightning
gen l_elec=(m1b_q12==1)
gen l_gen=(m1b_q12==2 | m1b_q12==3)
gen l_solar=(m1b_q12==4)
gen l_lamp=(m1b_q12==5|m1b_q12==6|m1b_q12==7|m1b_q12==97)
gen l_wood=(m1b_q12==8)

replace l_lamp=0 if m1b_q12==97 & m1b_q12_other=="Illegal from public network"
replace l_lamp=0 if m1b_q12==97 & m1b_q12_other=="NO COOKING"
replace l_lamp=0 if m1b_q12==97 & m1b_q12_other=="MOOONLIGHT"

factor l_* [aw=W_FinSPwt], mineigen(1)
alpha l_*, item detail
sum l_*

*toilet
gen to_flush=(m1b_q13==1|m1b_q13==2)
gen to_pit=(m1b_q13==3|m1b_q13==4|m1b_q13==5)
gen to_bucket=(m1b_q13==7)
gen to_public=(m1b_q13==5)
gen to_pool=(m1b_q13==6)
gen to_none=(m1b_q13==8)

gen to_shared1=(m1b_q14==1)

factor to_* [aw=W_FinSPwt], mineigen(1)
alpha to_*, item detail
sum to_*

*assets
gen a_cell1=(m1b_q15_1 ==1)
gen a_phone=(m1b_q15_2 ==1)
gen a_radio=(m1b_q15_3 ==1)
gen a_tv=(m1b_q15_4==1)
gen a_refri=(m1b_q15_5 ==1)
gen a_wash=(m1b_q15_6 ==1)
gen a_airc=(m1b_q15_7 ==1)
gen a_comp=(m1b_q15_8 ==1)
gen a_int=(m1b_q15_9==1)
gen a_bicy=(m1b_q15_10==1)
gen a_motorc=(m1b_q15_11==1)
gen a_three=(m1b_q15_12==1)
gen a_car=(m1b_q15_13==1)
gen a_animal=(m1b_q15_15==1)
gen a_boat=(m1b_q15_16==1|m1b_q15_17==1)
gen a_waterh=(m1b_q15_14==1)

factor a_* [aw=W_FinSPwt], mineigen(1)
alpha a_*, item detail
sum a_*

*Other ownerships
gen a2_sech=(m1b_q16_1 ==1)
gen a2_bank=(m1b_q16_2 ==1)
gen a2_ins=(m1b_q16_3 ==1)
gen a2_gard=(m1b_q16_4 ==1)
gen a2_agri=(m1b_q16_5 ==1)
gen a2_other=(m1b_q16_6 ==1)
gen a2_poul=(m1b_q16_7 ==1)

factor a2_* [aw=W_FinSPwt], mineigen(1)
alpha a2_*, item detail
sum a2_*

* Agr assets
gen ag_cow=(m1b_q17_1 >0 & m1b_q17_1 ~=.)
gen ag_donk=(m1b_q17_2 >0 & m1b_q17_2 ~=.)
gen ag_camels=(m1b_q17_3>0 & m1b_q17_3~=.)
gen ag_pigs=(m1b_q17_7 >0 & m1b_q17_7 ~=.)
gen ag_goat=(m1b_q17_4 >0 & m1b_q17_4 ~=.)
gen ag_sheep=(m1b_q17_5 >0 & m1b_q17_5 ~=.)
gen ag_chick=(m1b_q17_6 >0 & m1b_q17_6 ~=.)
gen ag_poul=(m1b_q17_8>0 & m1b_q17_8~=.)


factor ag_* [aw=W_FinSPwt], mineigen(1)
alpha ag_*, item detail
sum ag_*

* books
 gen book_0=(m1b_q18==1)
 gen book_1=(m1b_q18==2)
 gen book_11=(m1b_q18==3)
 gen book_51=(m1b_q18==4)
 gen book_fw=(m1b_q18==5)
 gen book_mn=(m1b_q18==6)
 
***************
* ASSET INDEX *
***************
  
*Distribution of assets
sum a_* a2_* d_* r_* f_* o_* w_*  c_* to_* ag_* room_* dw_* l_*
 
* Dropping highly skewed variables (mean <.02 or >.98) since all variables are indicator variables. 
drop a_phone a_wash a_three a_animal a_boat r_asbestos r_grass r_tin f_wood w_wood ///
	c_build c_not c_elec c_bio to_bucket to_pool to_none ag_camels ag_pigs room_5 room_6up ///
	dw_rain dw_bottle l_solar l_wood
	 
*Overview of all assets 
factor a_* a2_* d_* r_* f_* w_* o_* room_* c_* to_* dw_* l_* [aw=W_FinSPwt], mineigen(1) 
rotate, varimax
predict all_assets
alpha a_* a2_* d_* r_* f_* w_* o_* room_*  c_* to_* dw_* l_*
/*Comments: All asset have loading factors as could be expected, 13 egen values are above 1 and the first one explain 22.12%.
Cronbach's alpha at  0.8836 indicate a strong underlying measure*/

**** A look at "types" of assets 
*Dwelling
factor d_* r_* f_* w_* o_* room_* c_* dw_* to_* l_*[aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict dwelling
alpha d_* r_* f_* w_* o_* room_* c_*  dw_* to_* l_*
/*Dwelling has 12 egen values are above 1 and the first one only explain 11.62%.
Cronbach's Alpha at  0.8396 indicate a moderate underlying measure*/

*Assets 1
factor a_*  [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset1
alpha a_*
/*Assets1 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 100 % of variation, Cronbach's alpha at  0.7254 indicate
a strong underleying measure*/
 
*Assests 2
factor a2_*   [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict asset2
alpha a2_*
/*Assets2 do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 117 % of variation, Cronbach's alpha at  0.6565 indicate
a moderate underleying measure*/


*Agriculture
factor ag_* [aw=W_FinSPwt], mineigen(1)
rotate, varimax
predict agri
alpha ag_*
/*Agri do seem to represent a more concentrated underlying definition of wealth with 1 egenvalues 
over 1 and the first one explaing 119 % of variation, Cronbach's alpha at  0.7659 indicate
a moderate underleying measure*/

 
pwcorr all_assets dwelling asset1 asset2 [aw=W_FinSPwt], sig
/* asset seem to correlate well with overall asset index */

preserve
*Dropping agriculture related
drop a2_agri a2_poul ag_*

*Dropping assets not related to overall assets (<0.1 of factor loading, before rotation): 
drop a_motorc 

*Dropping secondary assets not related to overall assets (<0.1 of factor loading, before rotation):
/*none*/ 
 
*Dropping dwelling characteristics not related to overall assets (<0.1 of factor loading, before rotation):
drop d_house d_indiv o_own o_free o_rent room_2 dw_well dw_spring


***** Asset Index with remaining variables *********
factor a_* a2_* d_* r_* f_* w_*  room_* dw_* to_* l_* [aw=W_FinSPwt], mineigen(1) 
predict asset_index
alpha  a_* a2_* d_* r_* f_* w_*  room_* dw_* to_* l_*
/* Cronbach's Alpha: 0.8776 */

kdensity asset_index [aw=W_FinSPwt], nodraw

* Asset_q quintiles 
xtile asset_q=asset_index [aw=W_FinSPwt] , nq(5)

keep asset_q country asset_index idcode hhn cluster W_FinSPwt
sort cluster hhn idcode
save "$pathworkingdata/Temp.dta", replace
restore

* Merge to working data

clear all
u "$pathworkingdata/STEP Kenya_working.dta", replace
keep if elegido==1 & urban==1 & age>14

sort cluster hhn idcode

merge cluster hhn idcode using "$pathworkingdata/Temp.dta"
drop _merge
label var asset_index "Asset Wealth Index"
label var asset_q "Asset Wealth Index Quintiles"
save "$pathworkingdata/STEP Kenya_working.dta", replace

****************************************************** END OF STEP DO-FILE 6 **********************************************************
