********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 2: GENERATING DERIVED VARIABLES FROM THE LITERACY ASSESSMENT DATA
*
* Created by: T. Rajadel
* Modified by: Sebastian Monroy Taborda
* Created: August 1, 2013
* Last updated: May 21, 2014
********************************************************************************************************************

/*
As of April 28, 2014 the Wave 2 STEP countries are:
	- Ghana
	- Armenia
	- Georgia
	- Macedonia
	- Kenya

This do-file uses the STEP Working data files to generate derived variables from the literacy assessment data:
	1/ General Booklet
		- Scores for Section A of the General Booklet	
*/


global pathworkingdata

**************************************************************** LOOP THROUGH ALL COUNTRIES ********************************************************************

foreach country in "Armenia" "Georgia" "Ghana" "Macedonia" "Kenya"{

	use "$pathworkingdata/STEP `country'_working.dta", clear
	drop country
	gen country="`country'"
	
	** 1. GENERAL BOOKLET | SECTION A
	
	**	1.1. NUMBER OF CORRECT RESPONSES OBTAINED IN:
	**		- Part 1 Print Vocabulary - PV
	**		- Part 2 Sentence Processing - SP
	**		- Part 3 Passage Comprehension - PC
	
	gen ETS_vocabulary=0
	foreach x in P901002_score P904012_score P901003_score P901005_score P904009_score P901006_score P901004_score P902024_score P901020_score P901017_score P901019_score P904022_score P903017_score P904014_score P904015_score P904020_score P902022_score P901024_score P902014_score P903024_score P904024_score P904025_score P903021_score P901015_score P904021_score {
		replace ETS_vocabulary=ETS_vocabulary + `x' if `x'==1
	}
	replace ETS_vocabulary=. if DESIGN==1 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<=74 & m11_q07!=.))	// FULL literacy asst result codes
	replace ETS_vocabulary=. if DESIGN==2 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<76 & m11_q07!=.))	// PARTIAL Literacy asst result codes
	replace ETS_vocabulary=0 if m11_q07==61 | m11_q07==71
	lab var ETS_vocabulary "Number of correct responses obtained in Part 1 Print Vocabulary | Section A Gal Booklet"

	gen ETS_sentence=0
	foreach x in  P911001_score P912002_score P911003_score P911004_score P911005_score P911006_score P911007_score P911008_score P911009_score P913013_score P912011_score P914012_score P912013_score P911014_score P914015_score P914019_score P914016_score P914018_score P912019_score P911020_score {
		replace ETS_sentence=ETS_sentence + `x' if `x'==1
	}
	replace ETS_sentence=. if DESIGN==1 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<=74 & m11_q07!=.))	// FULL literacy asst result codes
	replace ETS_sentence=. if DESIGN==2 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<76 & m11_q07!=.))	// PARTIAL Literacy asst result codes
	replace ETS_sentence=0 if m11_q07==61 | m11_q07==71
	lab var ETS_sentence "Number of correct responses obtained in Part 2 Sentence Processing | Section A Gal Booklet"

	gen ETS_passage=0
	foreach x in P921002_score P921003_score P921004_score P921005_score P921007_score P921008_score P921009_score P921010_score P921011_score P921013_score P921014_score P921015_score P921016_score P921017_score P921018_score P921019_score P921020_score P921021_score P922023_score P922024_score P922025_score P922026_score P922027_score P922028_score P922030_score P922031_score P922032_score P922033_score P921035_score P921036_score P921037_score P921038_score P921040_score P921041_score P921042_score P921043_score {
		replace ETS_passage=ETS_passage + `x' if `x'==1
	}
	replace ETS_passage=. if DESIGN==1 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<=74 & m11_q07!=.))	// FULL literacy asst result codes
	replace ETS_passage=. if DESIGN==2 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<76 & m11_q07!=.))	// PARTIAL Literacy asst result codes
	replace ETS_passage=0 if m11_q07==61 | m11_q07==71
	lab var ETS_passage "Number of correct responses obtained in Part 3 Passage Comprehension | Section A Gal Booklet"

	* Generate Quartiles for each Reading Component
	xtile ETS_vocaq = ETS_vocabulary, nq(4)
	xtile ETS_sentq = ETS_sentence, nq(4)
	xtile ETS_passq = ETS_passage, nq(4)
	
	
	**	1.2. CORRECT RESPONSES & TIME
	**		Generate variables factoring in the time respondents took to answer questions
	**		- Part 1 Print Vocabulary - PV
	**		- Part 2 Sentence Processing - SP
	**		- Part 3 Passage Comprehension - PC
		
	foreach var in TIMEP1 TIMEP2 TIMEP3 TIMEP4 TIMEP5{
		replace `var'=. if `var'==9999
	}

	* PV and SP over timing 
	gen voc_timing=ETS_vocabulary/TIMEP1
	lab var voc_timing "ETS_vocabulary/TIMEP1"
	gen sent_timing=ETS_sentence/TIMEP2
	lab var sent_timing "ETS_sentence/TIMEP2"

	* Interaction PVxTiming and SPxTIming
	gen voc_int_timing=ETS_vocabulary*TIMEP1
	lab var voc_int_timing "ETS_vocabulary*TIMEP1"
	gen sent_int_timing=ETS_sentence*TIMEP2
	lab var sent_int_timing "ETS_sentence*TIMEP2"

	* Gen correct answers by passage 
	foreach var in P921002_score P921003_score P921004_score P921005_score P921007_score ///
				P921008_score P921009_score P921010_score P921011_score P921013_score ///
				P921014_score P921015_score P921016_score P921017_score P921018_score P921019_score ///
				P921020_score P921021_score P922023_score P922024_score P922025_score P922026_score ///
				P922027_score P922028_score P922030_score P922031_score P922032_score P922033_score ///
				P921035_score P921036_score P921037_score P921038_score P921040_score P921041_score ///
				P921042_score P921043_score {
	qui tab `var', gen(correct_`var')
	}

	egen pc_correct_part1=rowtotal(correct_P921002_score2 correct_P921003_score2 correct_P921004_score2 correct_P921005_score2 correct_P921007_score2 ///
				correct_P921008_score2 correct_P921009_score2 correct_P921010_score2 correct_P921011_score2 correct_P921013_score2 ///
				correct_P921014_score2 correct_P921015_score2 correct_P921016_score2 correct_P921017_score2 correct_P921018_score2 correct_P921019_score2 ///
				correct_P921020_score2 correct_P921021_score2), missing
	lab var pc_correct_part1 "# correct responses in Part 1 of Passage Comprehension"
	
	egen pc_correct_part2=rowtotal(correct_P922023_score2 correct_P922024_score2 correct_P922025_score2 correct_P922026_score2 ///
				correct_P922027_score2 correct_P922028_score2 correct_P922030_score2 correct_P922031_score2 correct_P922032_score2 correct_P922033_score2), missing
	lab var pc_correct_part2 "# correct responses in Part 2 of Passage Comprehension"

	egen pc_correct_part3=rowtotal(correct_P921035_score2 correct_P921036_score2 correct_P921037_score2 correct_P921038_score2 correct_P921040_score2 correct_P921041_score2 ///
				correct_P921042_score2 correct_P921043_score2), missing
	lab var pc_correct_part3 "# correct responses in Part 3 of Passage Comprehension"
	
	egen pc_timing_total=rowtotal(TIMEP3 TIMEP4 TIMEP5), missing
	lab var pc_timing_total "Passage Comprehension Timing Overall"
	order pc_timing_total, after(TIMEP5)

	* PC over timing
	gen pass_timing1=pc_correct_part1/TIMEP3
	gen pass_timing2=pc_correct_part2/TIMEP4
	gen pass_timing3=pc_correct_part3/TIMEP5
	gen pass_timing_all=ETS_passage/pc_timing_total
	lab var pass_timing1 "pc_correct_part1/TIMEP3"
	lab var pass_timing2 "pc_correct_part2/TIMEP4"
	lab var pass_timing3 "pc_correct_part3/TIMEP5"
	lab var pass_timing_all "ETS_passage/pc_timing_total"
	
	* Interaction PCxTiming
	gen pass_int_timing1=pc_correct_part1*TIMEP3
	gen pass_int_timing2=pc_correct_part2*TIMEP4
	gen pass_int_timing3=pc_correct_part3*TIMEP5
	gen pass_int_timing_all=ETS_passage*pc_timing_total
	lab var pass_int_timing1 "pc_correct_part1*TIMEP3"
	lab var pass_int_timing2 "pc_correct_part2*TIMEP4"
	lab var pass_int_timing3 "pc_correct_part3*TIMEP5"
	lab var pass_int_timing_all "ETS_passage*timing_total"

	drop correct*
	
	
	** 2. GENERAL BOOKLET | SECTION B - "CORE TEST"
	**		NUMBER OF CORRECT RESPONSES:
	**			- as scored by the survey firm after fieldwork
	**			- as scored by interviewers during fieldwork	// NOTE: interviewers' scores determined whether or not a respondent would take the extended assessment, but they should not be used in the analysis
	**
	**		PASSED OR FAILED THE "CORE TEST", i.e., 3 or more correct answers (out of 8 items)
		
	* 2.1. GENERATING ETS_CORE, NUMBER OF CORRECT CORE LITERACY ITEMS
	gen ETS_core=0
	replace ETS_core=ETS_core+1 if M301C05==1
	replace ETS_core=ETS_core+1 if M300C02==1
	replace ETS_core=ETS_core+1 if N000C01==1
	replace ETS_core=ETS_core+1 if P330001==1
	replace ETS_core=ETS_core+1 if P330002==1 
	replace ETS_core=ETS_core+1 if N302C02==1 
	replace ETS_core=ETS_core+1 if N311701==1
	replace ETS_core=ETS_core+1 if N311703==1
	
	replace ETS_core=. if DESIGN==1 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<=74 & m11_q07!=.))
		// FULL literacy asst result codes
		// Cases with result codes 51-52 and 62-65 are excluded, as the respondent did not / could not attempt the General Booklet
		// Pending guidance from ETS, cases with result codes 72-74 are excluded, as a circumstances prevented a proper assessment of the respondent's reading literacy
	replace ETS_core=. if DESIGN==2 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<76 & m11_q07!=.))
		// PARTIAL Literacy asst result codes
		// Cases with result codes 51-52 and 62-65 are excluded, as the respondent did not / could not attempt the General Booklet
		// Pending guidance from ETS, cases with result codes 72-75 are excluded, as a circumstances prevented a proper assessment of the respondent's reading literacy
	replace ETS_core=0 if m11_q07==61 | m11_q07==71	
	
	lab var ETS_core "Scored after fieldwork: Number of correct responses obtained in the Core Test, Section B | Gal Booklet"
	
	gen ETS_coreI=0
	replace ETS_coreI=ETS_coreI+1 if M301C05I==1
	replace ETS_coreI=ETS_coreI+1 if M300C02I==1
	replace ETS_coreI=ETS_coreI+1 if N000C01I==1
	replace ETS_coreI=ETS_coreI+1 if P330001I==1
	replace ETS_coreI=ETS_coreI+1 if P330002I==1 
	replace ETS_coreI=ETS_coreI+1 if N302C02I==1 
	replace ETS_coreI=ETS_coreI+1 if N311701I==1
	replace ETS_coreI=ETS_coreI+1 if N311703I==1
	
	replace ETS_coreI=. if DESIGN==1 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<=74 & m11_q07!=.))
		// FULL literacy asst result codes
		// Cases with result codes 51-52 and 62-65 are excluded, as the respondent did not / could not attempt the General Booklet
		// Pending guidance from ETS, cases with result codes 72-74  are excluded, as a circumstances prevented a proper assessment of the respondent's reading literacy
	replace ETS_coreI=. if DESIGN==2 & ((m11_q07>=51 & m11_q07<=65 & m11_q07!=.) | (m11_q07>=72 & m11_q07<76 & m11_q07!=.))
		// PARTIAL Literacy asst result codes
		// Cases with result codes 51-52 and 62-65 are excluded, as the respondent did not / could not attempt the General Booklet
		// Pending guidance from ETS, cases with result codes 72-75  are excluded, as a circumstances prevented a proper assessment of the respondent's reading literacy
	replace ETS_coreI=0 if m11_q07==61 | m11_q07==71
		// Result codes 61 & 71 correspond to respondents unable to read or write the language in which the Booklet was written, they are categorised as not having passed the Core Test

	lab var ETS_coreI "Scored by the Interviewer during fieldwork: Number of correct responses obtained in the Core Test, Section B | Gal Booklet"
	
	
	* 2.2. GENERATES A VARIABLE INDICATING WHETHER A RESPONDENT PASSED/FAILED THE CORE TEST (SECTION B OF THE GENERAL BOOKLET)
	gen ETS_core_pass=1 if ETS_core>=3 & ETS_core!=.
	replace ETS_core_pass=0 if ETS_core<3 & ETS_core!=.
	lab var ETS_core_pass "Whether respondent passed the Core test (>=3/8 correct answers in Section B | Gal Booklet)"
	lab values ETS_core_pass yesno
	

	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


************************************************** END OF STEP DO-FILE 2 ******************************************************
