********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 4: FAMILY-RELATED VARIABLES
*
* Created by: N. Millan's January 7, 2013 do-file
* Modified by: Sebastian Monroy Taborda
* Created: January 7, 2013
* Last updated: April 28, 2014
********************************************************************************************************************

/*
As of April 28, 2014 the wave 2 STEP countries are:
	- Ghana
	- Armenia
	- Georgia
	- Macedonia
	- Kenya


This do-file uses the STEP Working data files to generate family-related variables using the household questionnaire data (Module 7).

It is based on Natalia Millan's January 7, 2013 do-file.
*/

global pathworkingdata
global pathdataready


**************************************************************** LOOP THROUGH ALL COUNTRIES ************************************************************************
foreach country in "Armenia" "Georgia" "Ghana" "Macedonia" "Kenya" {
	use "$pathworkingdata/STEP `country'_working.dta", clear

	sort cluster hhn idcode
	save "$pathworkingdata/STEP `country'_working.dta", replace
	
	use "$pathdataready/STEP `country'_HH_Roster_S10.dta", replace
	keep cluster hhn idcode m1a*
	sort cluster hhn idcode
	merge m:1 cluster hhn idcode using "$pathworkingdata/STEP `country'_working.dta"
	drop _merge

	drop country
	gen country="`country'"

	if country=="Macedonia" {
	/* Renaming variables in module 7*/
	rename m7a_q01_1 m7_q01_1
	rename m7a_q01_2 m7_q01_2
	rename m7a_q01_other m7_q01_other
	rename m7a_q02 m7_q02
	rename m7a_q02_other m7_q02_other
	rename m7a_q03 m7_q03
	rename m7a_q04 m7_q04
	rename m7a_q05_a_s m7_q05_a_s
	rename m7a_q05_a_rw m7_q05_a_rw
	rename m7a_q05_b_s m7_q05_b_s
	rename m7a_q05_b_rw m7_q05_b_rw
	rename m7a_q05_c_s m7_q05_c_s
	rename m7a_q05_c_rw m7_q05_c_rw
	rename m7a_q05_d_s m7_q05_d_s
	rename m7a_q05_d_rw m7_q05_d_rw
	rename m7a_q05_e_s m7_q05_e_s
	rename m7a_q05_e_rw m7_q05_e_rw
	rename m7a_q05_f_s m7_q05_f_s
	rename m7a_q05_f_rw m7_q05_f_rw
	rename m7a_q05_g_s m7_q05_g_s
	rename m7a_q05_g_rw m7_q05_g_rw
	rename m7a_q05_h_s m7_q05_h_s
	rename m7a_q05_h_rw m7_q05_h_rw
	rename m7a_q05_i_s m7_q05_i_s
	rename m7a_q05_i_rw m7_q05_i_rw
	rename m7a_q05_other_1 m7_q05_other_1
	rename m7a_q05_other_2 m7_q05_other_2
	rename m7a_q06 m7_q06
	rename m7a_q07 m7_q07
	rename m7a_q08_1 m7_q08_1
	rename m7a_q09 m7_q09
	rename m7a_q10_1 m7_q10_1
	rename m7a_q10_2 m7_q10_2
	rename m7a_q10_3 m7_q10_3
	rename m7a_q10_4 m7_q10_4
	rename m7a_q10_5 m7_q10_5
	rename m7a_q10_6 m7_q10_6
	rename m7a_q10_7 m7_q10_7
	rename m7a_q10_8 m7_q10_8
	rename m7a_q10_9 m7_q10_9
	rename m7a_q10_10 m7_q10_10
	rename m7a_q11 m7_q11
	rename m7a_q12 m7_q12
	rename m7a_q13 m7_q13
	rename m7a_q14 m7_q14
	rename m7a_q15 m7_q15
	rename m7a_q16 m7_q16
	rename m7a_q17 m7_q17
	rename m7a_q18 m7_q18
	rename m7a_q19 m7_q19
	rename m7a_q20 m7_q20
	rename m7a_q21_1 m7_q21_1
	rename m7a_q21_2 m7_q21_2
	rename m7a_q21_3 m7_q21_3
	rename m7a_q21_4 m7_q21_4
	rename m7a_q21_5 m7_q21_5
	rename m7a_q21_6 m7_q21_6
	rename m7a_q21_7 m7_q21_7
	rename m7a_q21_8 m7_q21_8
	rename m7a_q21_9 m7_q21_9
	rename m7a_q21_10 m7_q21_10
	rename m7a_q21_11 m7_q21_11
	rename m7a_q21_12 m7_q21_12
	rename m7a_q21_13 m7_q21_13
	rename m7a_q21_14 m7_q21_14
	rename m7a_q21_14_other m7_q21_14_other
	rename m7a_q22 m7_q22
	rename m7a_q23_1 m7_q23_1
	rename m7a_q23_2 m7_q23_2
	rename m7a_q23_3 m7_q23_3
	rename m7a_q23_4 m7_q23_4
	rename m7a_q23_5 m7_q23_5
	rename m7a_q23_6 m7_q23_6
	rename m7a_q23_7 m7_q23_7
	rename m7a_q23_8 m7_q23_8
	rename m7a_q23_9 m7_q23_9
	rename m7a_q23_10 m7_q23_10
	rename m7a_q23_11 m7_q23_11
	rename m7a_q23_12 m7_q23_12
	rename m7a_q23_12_other m7_q23_12_other
	rename m7a_q24 m7_q24
	rename m7a_q25 m7_q25
	}
	
	
	if country=="Macedonia" {
	
	* Correcting labels for mother's and father's education. 
	recode m7_q16 (8=7)
	
	label define m7_q13 -9 "DK" 1 "No formal Education or Less than Complete Lower Primary" 2 "Lower primary complete" 3 "High Primary" 4 "Secondary (vocational, gymnasium, religious secondary)" 5 "Post-Secondary specialist/Professional College" 6 "Bachelor, Master Degree" 7 "Doctorate Degree", modify
	label values m7_q13 m7_q13
	label values m7_q16 m7_q13
	
	tab m7_q13, m
	tab m7_q16, m
	
		*MOTHER'S EDUCATION
		gen mother_educ=0 if m7_q13==1								/* No education */
		replace mother_educ=0 if m7_q13==2							/*<ISCED 1*/
		replace mother_educ=1 if m7_q13==3							/*ISCED 1*/
		replace mother_educ=2 if m7_q13==4							/*ISCED 2 and 3*/
		replace mother_educ=3 if m7_q13==5 | m7_q13==6 | m7_q13==7 	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q12)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   	/*ISCED < 1*/
		replace xy=1 if xxx==3      	/*ISCED 1*/
		replace xy=2 if xxx==4 			/*ISCED 2*/
		replace xy=2 if xxx==5 			/*ISCED 3*/
		replace xy=3 if xxx==7 |xxx==6 	/*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 
		tab mother_educ
		
		*FATHER'S EDUCATION
		gen father_educ=0 if m7_q16==1									/* No education */
		replace father_educ=0 if m7_q16==2								/*<ISCED 1*/
		replace father_educ=1 if m7_q16==3								/*ISCED 1*/
		replace father_educ=2 if m7_q16==4								/*ISCED 2 and 3*/
		replace father_educ=3 if m7_q16==5 | m7_q16==6 | m7_q16==7 	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q15)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   	/*ISCED < 1*/
		replace xy=1 if xxx==3      	/*ISCED 1*/
		replace xy=2 if xxx==4 			/*ISCED 2*/
		replace xy=2 if xxx==5 			/*ISCED 3*/
		replace xy=3 if xxx==7 |xxx==6 	/*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var father_edu "father's education"
		tab father_educ
	}
	
	if country=="Kenya" {
		*MOTHER'S EDUCATION
		gen mother_educ=0 if m7_q13==1					/* No education */
		replace mother_educ=1 if m7_q13==2				/* ISCED 1*/
		replace mother_educ=2 if inrange(m7_q13,3,6)	/*ISCED 2 and 3*/
		replace mother_educ=3 if inrange(m7_q13,7,16)  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q12)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3 /*ISCED 1*/
		replace xy=2 if xxx==4 | xxx==5 /*ISCED 2 & 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 
		tab mother_educ

		*FATHER'S EDUCATION
		gen father_educ=0 if m7_q16==1					/* No education */
		replace father_educ=1 if m7_q13==2				/* ISCED 1*/
		replace father_educ=2 if inrange(m7_q16,3,6)	/*ISCED 2 and 3*/
		replace father_educ=3 if inrange(m7_q16,7,16)  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q15)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3 /*ISCED 1*/
		replace xy=2 if xxx==4 | xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var father_edu "father's education"
		tab father_educ
		
		/* Assumption: Parents are slighlty more likeliy to be on primary education on old system, 
		thus, those who responded to primary education are put in ISCED 1 instead of ISCED 2A.*/
		
	}
	
	
	if country=="Ghana" {
		*MOTHER'S EDUCATION
		gen mother_educ=. if m7_q13==1								/* No education */
		replace mother_educ=0 if m7_q13==2							/*<ISCED 1*/
		replace mother_educ=1 if m7_q13==3							/*ISCED 1*/
		replace mother_educ=2 if m7_q13==6 | m7_q13==5 |m7_q13==4	/*ISCED 2 and 3*/
		replace mother_educ=3 if m7_q13==7 | m7_q13==8			  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q12)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 

		*FATHER'S EDUCATION
		gen father_educ=. if m7_q16==1								/* No education */
		replace father_educ=0 if m7_q16==2							/*<ISCED 1*/
		replace father_educ=1 if m7_q16==3							/*ISCED 1*/
		replace father_educ=2 if m7_q16==6 | m7_q16==5 |m7_q16==4	/*ISCED 2 and 3*/
		replace father_educ=3 if m7_q16==7 | m7_q16==8			  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q15)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1|xxx==2   /*ISCED < 1*/
		replace xy=1 if xxx==3      /*ISCED 1*/
		replace xy=2 if xxx==4 /*ISCED 2*/
		replace xy=2 if xxx==5 /*ISCED 3*/
		replace xy=3 if xxx==7|xxx==8|xxx==6 /*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var father_edu "father's education"
	}
	

	if country=="Armenia" {
		*MOTHER'S EDUCATION
		gen mother_educ=. if m7_q13==1								/* No education & < ISCED 1 */
		replace mother_educ=1 if m7_q13==2							/*ISCED 1*/
		replace mother_educ=2 if m7_q13==3 | m7_q13==4				/*ISCED 2 and 3*/
		replace mother_educ=3 if inrange(m7_q13,5,9)			  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q12)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy=. if xxx==1   /* No education & < ISCED 1 */
		replace xy=1 if xxx==2      /*ISCED 1*/
		replace xy=2 if xxx==3 /*ISCED 2*/
		replace xy=2 if xxx==4 /*ISCED 3*/
		replace xy=3 if xxx==5|xxx==6|xxx==7|xxx==8|xxx==9 /*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 
		tab mother_edu, m
		

		*FATHER'S EDUCATION
		gen father_educ=. if m7_q15==1								/* No education & < ISCED 1 */
		replace father_educ=1 if m7_q15==2							/*ISCED 1*/
		replace father_educ=2 if m7_q15==3 | m7_q15==4				/*ISCED 2 and 3*/
		replace father_educ=3 if inrange(m7_q15,5,9)			  	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q15)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9
		bysort cluster hhn: egen xxx=max(temp)  /*father's id code*/
		replace xxx=. if elegido!=1
		gen xy=. if xxx==1   /* No education & < ISCED 1 */
		replace xy=1 if xxx==2      /*ISCED 1*/
		replace xy=2 if xxx==3 /*ISCED 2*/
		replace xy=2 if xxx==4 /*ISCED 3*/
		replace xy=3 if xxx==5|xxx==6|xxx==7|xxx==8|xxx==9 /*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var father_edu "father's education"
		tab father_edu,m 
	}
	
	if country=="Georgia" {
		*MOTHER'S EDUCATION
		gen mother_educ=0 if m7_q13==1											/* No education or <ISCED 1 */
		replace mother_educ=1 if m7_q13==2										/*ISCED 1*/
		replace mother_educ=2 if m7_q13==3 | m7_q13==4 							/*ISCED 2 and 3*/
		replace mother_educ=3 if m7_q13==5 | m7_q13==6 | m7_q13==7 |m7_q13==8	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q12)  /*Mother's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9 | m1a_q09==-7 | m1a_q09==-3
		bysort cluster hhn: egen xxx=max(temp)  /*Mother's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1 | xxx==2 	 					/*No Education or ISCED < 1*/
		replace xy=1 if xxx==3      						/*ISCED 1*/
		replace xy=2 if xxx==4 								/*ISCED 2*/
		replace xy=2 if xxx==5  							/*ISCED 3*/
		replace xy=3 if xxx==6 | xxx==7 | xxx==8 | xxx==9 	/*ISCED 4 and above*/

		replace mother_educ=xy if mother_educ==.
		replace mother_educ=4 if mother_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var mother_edu "Mother's education" 
		tab mother_edu, m
		
		*FATHER'S EDUCATION
		gen father_educ=0 if m7_q16==1								/* No education or <ISCED 1 */
		replace father_educ=1 if m7_q16==2							/*ISCED 1*/
		replace father_educ=2 if m7_q16==3 | m7_q16==4 				/*ISCED 2 and 3*/
		replace father_educ=3 if m7_q16==5 | m7_q16==6 | m7_q16==7 |m7_q16==8	/*ISCED 4 & above*/

		bysort cluster hhn: egen x=max(m7_q15)  /*father's id code*/
		gen temp=m1a_q09 if idcode==x 
		replace temp=. if m1a_q09==-9 | m1a_q09==-7 | m1a_q09==-3
		bysort cluster hhn: egen xxx=max(temp)  /*Father's id code*/
		replace xxx=. if elegido!=1
		gen xy= 0 if xxx==1 | xxx==2 	 					/*No Education or ISCED < 1*/
		replace xy=1 if xxx==3      						/*ISCED 1*/
		replace xy=2 if xxx==4 								/*ISCED 2*/
		replace xy=2 if xxx==5  							/*ISCED 3*/
		replace xy=3 if xxx==6 | xxx==7 | xxx==8 | xxx==9 	/*ISCED 4 and above*/

		replace father_educ=xy if father_educ==.
		replace father_educ=4 if father_educ==. /*DK/MISSING*/
		drop x* temp
	
		label var father_edu "father's education"
	}
	
	*NUMBER OF CHILDREN UNDER 6 YEARS OLD 
	*Number under 6
	
	gen x=1 if m1a_q04<6
	bysort cluster hhn: egen temp=sum(x)
	bysort cluster hhn: egen children=max(temp)
	replace children =. if elegido!=1  
	label var children "Number of children under 6 years old" 
	drop x* temp

	gen _children0=1 if children==0
	recode _children0 (.=0)

	gen _children1=1 if children==1
	recode _children1 (.=0)

	gen _children2=2 if children>=2 & children!=.
	recode _children2 (.=0)
	
	if country=="Georgia"{
		recode m7_q09 (0=2)
	}
	gen has_children=1 if m7_q09 ==1
	replace has_children=0 if m7_q09==2
	
	
	lab var has_children "respondent is the parent of a child in the hh"
	lab var _children0 "1: no children under 6 in the hh"
	lab var _children1 "1: one child under 6 in the hh"
	lab var _children2 "2: 2 or more children under 6 in the hh"
	

	*Number under 6 that belong to the respondent (pending)
	/*foreach num in numlist 1/10 {
	bysort cluster hhn: egen temp`num'=max(m7a_q11_`num')  /*Child's id code*/
	gen age`num'=m1a_q04 if idcode==temp`num'
	}*/

	*LABOR MARKET DEPENDENCY 
	/*Number of working hh members/total hh members*/
	mvdecode m1a*, mv(-9/-1=.)
	
	gen temp1=1 if m1a_q03!=12 & m1a_q03!=. /*DO NOT COUNT NON RELATIVES AS HH MEMBERS SINCE MANY OF THESE ARE ACTUALLY HH SERVANTS, YET SURVEYS DON'T ALWAYS SPECIFY*/

	bysort cluster hhn: egen hh_size=sum(temp1)
	label var hh_size "HH size, excludes non-relatives"
	
	if country=="Georgia"{
	foreach var of varlist	m4a_q01 m4a_q02 m4a_q03 m4a_q04 m4a_q05 m4a_q06 m4a_q07 m4a_q08 ///
							m4a_q10_01 m4a_q10_02 m4a_q10_03 m4a_q10_04 m4a_q10_05 m4a_q10_06 ///
							m4a_q10_07 m4a_q10_08 m4a_q10_09 m4a_q12 m4a_q14 m4a_q16 m4a_q17 ///
							m4a_q18 m4a_q23 m4a_q26 m4a_q27 m4a_q29 {
		recode `var' (0=2)
		label values `var' yes_no
	}
	}
	gen temp4=1 if m4a_q01==1|m4a_q02==1|m4a_q03==1|m4a_q04==1|m4a_q05==1|m4a_q06==1
	replace temp4=0 if m4a_q01==2 & m4a_q02==2 & m4a_q03==2 & m4a_q04==2 & m4a_q05==2 
	replace temp4=0 if m4a_q06==2
	replace temp4=. if m4a_q06==9

	gen temp2=1 if m1a_q14==1 & temp1==1
	replace temp2=1 if temp4==1 & temp1==1
	replace temp2=. if temp4==0 & temp1==1

	bysort cluster hhn: egen temp3=sum(temp2)  /*Number of working members */
	gen labor_dep=temp3/hh_size 
	label var labor_dep "# employed hh members / hh_size" 
	drop  temp*
	
	*LABEL VARIABLES, GENERATE MAX PARENTS' EDUC
	tab mother_educ
	tab father_educ
	*MAX OF FATHER'S OR MOTHER'S EDUCATION
	gen temp_father=father_educ
	replace temp_father=. if father_educ==4
	gen temp_mother=mother_educ
	replace temp_mother=. if mother_educ==4
	egen max_parent_educ=rowmax(temp_father temp_mother)
	label var max_parent_educ "Maximum of parents' education"
	recode max_parent_educ .=4 if elegido==1
	drop temp*
	tab max_parent_educ

	label define parent_edu 0 "<ISCED 1" 1 "ISCED 1" 2 "ISCED 2 & 3" 3 "ISCED 4 & higher" 4 "DK/RF", replace
	label values mother_educ parent_edu
	label values father_educ parent_edu
	label values max_parent_educ parent_edu
	order max_parent, after(father_ed)

	keep if elegido==1

	if country=="Armenia" | country=="Ghana" | country=="Georgia" {
	order  m1a_q01-m1a_q20, after(N15)
	compress
	sort cluster hhn idcode
	}
	if country=="Macedonia" {
	compress
	sort cluster hhn idcode
	}
	
	if country=="Kenya"{
	order m1a_q02-m1a_q20, after(n15)
	compress 
	sort cluster hhn idcode
	}
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


**************************************************************************** END OF STEP DO-FILE 4 ******************************************************************
