********************************************************************************************************************
* STEP | GENERATING DERIVED VARIABLES FROM THE BACKGROUND QUESTIONNAIRE & LITERACY ASSESSMENT DATA
*
*	DO-FILE 3: SKILLS AGGREGATION
*
* Created by: N. Millan's December 6, 2012 do-file
* Modified by: Sebastian Monroy Taborda
* Created: December 6, 2012
* Last updated: May 21, 2014
********************************************************************************************************************

/*
As of April 28, 2014 the wave 2 STEP countries are:
	- Ghana
	- Armenia
	- Georgia
	- Macedonia
	- Kenya

This do-file uses the STEP Working data files to generate aggregate variables for different type of skills (based on the household questionnaire data).

It is based on Natalia Millan's December 6, 2012 do-file.
*/


global pathworkingdata


**************************************************************** LOOP THROUGH ALL COUNTRIES ************************************************************************
foreach country in "Armenia" "Georgia" "Ghana" "Macedonia" "Kenya" {
use "$pathworkingdata/STEP `country'_working.dta", clear
drop country
gen country="`country'"
	***********COGNITIVE************************************
****READING**********
if country=="Georgia" {
label define yes_no 1 "Yes" 2 "No" -7 "Legal Skip" -3 "interviewer error", modify
foreach var of varlist m5a_q01 m5a_q02 m5a_q04 m5a_q05_1 m5a_q05_2 m5a_q05_3 ///
					m5a_q05_4 m5a_q05_5 m5a_q05_6 m5a_q08 m5a_q09_1 m5a_q09_2 m5a_q09_3 ///
					m5a_q09_4 m5a_q09_5 m5a_q09_6 m5a_q11 m5a_q12 m5a_q15 m5a_q16 ///
					m5a_q18_1 m5a_q18_2 m5a_q18_3 m5a_q18_4 m5a_q18_5 m5a_q18_6 m5a_q19_1 ///
					m5a_q19_2 m5a_q19_3 m5a_q19_4 m5a_q19_5 m5a_q19_6 m5a_q20 m5a_q21 m5a_q22_1 ///
					m5a_q22_2 m5a_q22_3 m5a_q22_4 m5a_q22_5 m5a_q22_6 m5a_q24 m5a_q25 m5a_q27_1 ///
					m5a_q27_2 m5a_q27_3 m5a_q27_4 m5a_q27_5 m5a_q27_6 {
recode `var' (0=2)
label values `var' yes_no
}
}					

if country=="Kenya"{
mvdecode m5a* m5b*, mv(-99/-44=.)
}
	*at work
gen read_work=.
replace read_work=0 if m5a_q06==6 | m5a_q04==2 
replace read_work=1 if m5a_q06==1 | m5a_q06==2
replace read_work=2 if m5a_q06==3 | m5a_q06==4
replace read_work=3 if m5a_q06==5
tab read_work, m 

	*outside work
gen read_outside=.
replace read_outside=0 if m5a_q07==6| m5a_q08==2 | m5a_q21==2| m5a_q10==6| m5a_q23==6
replace read_outside=1 if m5a_q07==1|  m5a_q07==2 |m5a_q10==1| m5a_q10==2 |m5a_q23==1 |m5a_q23==2
replace read_outside=2 if m5a_q07==3|  m5a_q07==4 |m5a_q10==3| m5a_q10==4 |m5a_q23==3 |m5a_q23==4
replace read_outside=3 if m5a_q07==5 |m5a_q10==5|m5a_q23==5
tab read_outside, m 
	*overall
gen read=max(read_work, read_outside)
tab read, m


*** WRITING***
**writing length****
	*at work
gen write_work=.
replace write_work=0 if m5a_q13==6 | m5a_q12==2 
replace write_work=1 if m5a_q13==1 | m5a_q13==2
replace write_work=2 if m5a_q13==3 | m5a_q13==4
replace write_work=3 if m5a_q13==5
tab write_work, m

	*outside work
gen write_outside=.
replace write_outside=0 if m5a_q16==2 | m5a_q25==2 | m5a_q14==6 | m5a_q17==6 | m5a_q26==6
replace write_outside=1 if m5a_q14==1 | m5a_q14==2 | m5a_q17==1 | m5a_q17==2 | m5a_q26==1 | m5a_q26==2
replace write_outside=2 if m5a_q14==3 | m5a_q14==4 | m5a_q17==3 | m5a_q17==4 | m5a_q26==3 | m5a_q26==4
replace write_outside=3 if m5a_q14==5 | m5a_q17==5 | m5a_q26==5
tab write_outside, m

	*overall
gen write=max(write_work, write_outside)
tab write, m


***************************
**SELF-REPORT NUMERACY
****************************


*NUMERACY: intensity (Question 1 counts as one)
gen num_work=.
replace num_work=1 if m5a_q18_3==1 | m5a_q18_2==1 | m5a_q18_1==1
replace num_work=2 if m5a_q18_4==1 
replace num_work=3 if m5a_q18_5==1
replace num_work=0 if m5a_q18_4==2 & m5a_q18_2==2 & m5a_q18_1==2 & m5a_q18_3==2 & m5a_q18_5==2

if country=="Georgia"{
	replace num_work=3 if m5a_q18_6==1 & m5a_q18_6_other=="drawing geometry"
	replace num_work=1 if m5a_q18_6==1 & m5a_q18_6_other=="adding and subtracting"
	replace num_work=2 if m5a_q18_6==1 & m5a_q18_6_other=="exell charts"
}	

if country=="Ghana" | country=="Armenia"{
	replace num_work=3 if m5a_q18_6==1
}

if country=="Kenya" {
	replace num_work=3 if m5a_q18_6==1 & (m5a_q18_6_other=="Actuarial systems" | m5a_q18_6_other=="Advanced Statistics" | m5a_q18_6_other=="CHI-SQUARE" | m5a_q18_6_other=="Engineering models" | m5a_q18_6_other=="Forecasting" |m5a_q18_6_other=="USE PIE CHARTS AND BAR GRPAHS" | m5a_q18_6_other=="Other maths, lots of it he sai")
}

gen num_outside=.
replace num_outside=1 if m5a_q19_3==1 | m5a_q19_2==1 | m5a_q19_1==1 | m5a_q27_3==1 | m5a_q27_2==1| m5a_q27_1==1
replace num_outside=2 if m5a_q19_4==1 | m5a_q27_4==1 
replace num_outside=3 if m5a_q19_5==1 | m5a_q27_5==1

if country=="Georgia"{
	replace num_work=3 if m5a_q19_6==1 & m5a_q19_6_other=="drawing geometry" | m5a_q19_6_other=="calculus" |m5a_q19_6_other=="further mathematics"
	replace num_work=1 if m5a_q19_6==1 & m5a_q19_6_other=="adding and subtracting"
}	

if country=="Ghana" | country=="Armenia"{
	replace num_outside=3 if m5a_q19_6==1
}

if country=="Kenya" {
	replace num_work=3 if m5a_q18_6==1 & (m5a_q18_6_other=="Actuarial systems" | m5a_q18_6_other=="Advanced Statistics" | m5a_q18_6_other=="EXCEL")
}

replace num_outside=0 if m5a_q19_4==2 & m5a_q19_2==2 & m5a_q19_1==2 & m5a_q19_3==2 & m5a_q19_5==2 
replace num_outside=0 if m5a_q27_4==2 & m5a_q27_2==2 & m5a_q27_1==2 & m5a_q27_3==2 & m5a_q27_5==2
	
*OVERALL NUMERACY
tab num_work
tab num_outside

gen num=max(num_work, num_outside)
tab num_work
tab num_outside
tab num

***********************
*****TECHNICAL*********
***********************
if country=="Georgia"{
foreach var of varlist m5b_q01 m5b_q02 m5b_q05 m5b_q07 m5b_q08 m5b_q09 m5b_q12 m5b_q13 m5b_q15_1 ///
						m5b_q15_2 m5b_q18 m5b_q20_1 m5b_q20_2 m5b_q20_3 m5b_q20_4 m5b_q20_5 m5b_q20_6 ///
						m5b_q21 m5b_q22_1 m5b_q22_2 m5b_q22_3 m5b_q22_4 m5b_q22_5 m5b_q22_6 m5b_q22_7 ///
						m5b_q22_8 m5b_q22_9 m5b_q27 m5b_q28 m5b_q29_1 m5b_q29_2 m5b_q29_3 m5b_q30 ///
						m5b_q32 m5b_q33_1 m5b_q33_2 m5b_q33_3 m5b_q33_4 m5b_q33_5 m5b_q33_6 m5b_q33_7 ///
						m5b_q33_8 m5b_q33_9 m5b_q33_10 m5b_q34 m5b_q36_1 m5b_q36_2 m5b_q36_3 ///
						m5b_q36_4 m5b_q36_5 {
	recode `var' (0=2)
	label values `var' yes_no
}
}


**interpersonal_external and internal**
gen interpers_ex=.
replace interpers_ex=0 if m5b_q05==2
replace interpers_ex=1 if m5b_q06>=1 & m5b_q06<=4
replace interpers_ex=2 if m5b_q06>=5 & m5b_q06<=7
replace interpers_ex=3 if m5b_q06>=8 & m5b_q06<=10

gen present=. 
replace present=1 if  m5b_q12==1
replace present=0 if m5b_q12==2

gen supervise=.
replace supervise=1 if m5b_q13==1
replace supervise=0 if m5b_q13==2

/*interpers_in=.
gen interpers_in=0 if m5b_q10==2 & m5b_q11==2
replace interpers_in=1 if m5b_q10==1 | m5b_q11==1*/

**use of technology
	*******************************
	*computer frequency
	*******************************
	*at work

gen comp_work=.
replace comp_work=0 if m5b_q18==2|m5b_q19==4 
replace comp_work=1 if m5b_q19==3
replace comp_work=2 if m5b_q19==2
replace comp_work=3 if m5b_q19==1
tab comp_work, m
	*outside of work
gen comp_outside=.
replace comp_outside=0 if m5b_q30==2 |m5b_q31==4
replace comp_outside=1 if m5b_q31==3
replace comp_outside=2 if m5b_q31==2
replace comp_outside=3 if m5b_q31==1
tab comp_outside, m
	*overall
gen computer=max(comp_work, comp_outside)
tab computer, m


*Computer Type

gen computertype=0 if m5b_q18==2
replace computertype=1 if m5b_q20_1==1 | m5b_q20_2==1 | m5b_q20_3==1| m5b_q20_4==1
replace computertype=2 if m5b_q20_5==1 | m5b_q22_1==1 | m5b_q22_2==1 | m5b_q22_3==1 | m5b_q22_4==1 | m5b_q22_5==1 | m5b_q22_6==1 | m5b_q22_7==1 | m5b_q22_8==1
tab computertype,m

if country=="Georgia" {
	replace computertype=1 if m5b_q22_9==1 & (m5b_q22_9_other=="Repeit of cartridges" | m5b_q22_9_other=="outlook" | m5b_q22_9_other=="program for documents")
	replace computertype=2 if m5b_q22_9==1 & (m5b_q22_9_other=="architect programs" | m5b_q22_9_other=="mia programs" | m5b_q22_9_other=="police special program" | m5b_q22_9_other=="video-montage")
}

if country=="Macedonia" {
	replace computertype=2 if m5b_q22_9==1 
/*
They are all advanced computer software	
     (5b_22): Other Specification |      Freq.     Percent        Cum.
----------------------------------+-----------------------------------
                       corel draw |          2       14.29       14.29
             e-journal for school |          1        7.14       21.43
                           matlab |          1        7.14       28.57
                 network software |          1        7.14       35.71
               photoshop software |          1        7.14       42.86
                     sap software |          1        7.14       50.00
                security networks |          1        7.14       57.14
software for computerized machine |          1        7.14       64.29
        special designed software |          2       14.29       78.57
    specific internet web program |          2       14.29       92.86
                 trigger software |          1        7.14      100.00
*/
}


if country=="Kenya" {
	replace computertype=2 if m5b_q22_9==1 & (m5b_q22_9_other=="Frooty Loops" | m5b_q22_9_other=="Othe database management" | m5b_q22_9_other=="health information system")
	replace computertype=1 if m5b_q22_9==1 & (m5b_q22_9_other=="timing")
}	


*drive, repair, operate at work

gen drive=1 if m5b_q07==1
replace drive=0 if m5b_q07==2

gen repair=1 if m5b_q08==1 
replace repair=0 if m5b_q08==2

gen operate=1 if m5b_q09 ==1
replace operate=0 if m5b_q09==2


**cognitive challenge

gen think=.
replace think=0 if m5b_q10==1
replace think=1 if m5b_q10==2
replace think=2 if m5b_q10==3
replace think=2 if m5b_q10==4
replace think=3 if m5b_q10==5

gen learn=.
replace learn=0 if m5b_q17==5
replace learn=1 if m5b_q17==3
replace learn=1 if m5b_q17==4
replace learn=2 if m5b_q17==2
replace learn=3 if m5b_q17==1

gen cogchall_avg=(think+learn)/2
gen cogchall=.
replace cogchall=0 if cogchall_avg==0
replace cogchall=1 if cogchall_avg>=0.5 & cogchall_avg<=1
replace cogchall=2 if cogchall_avg>=1.5 & cogchall_avg<=2
replace cogchall=3 if cogchall_avg>=2.5 & cogchall_avg<=3

tab cogchall, m

**autonomy and repetitiveness
gen autonomy=.
replace autonomy=0 if m5b_q14>=1 & m5b_q14<=2
replace autonomy=1 if m5b_q14>=3 & m5b_q14<=6
replace autonomy=2 if m5b_q14>=7 & m5b_q14<=9
replace autonomy=3 if m5b_q14==10

gen repet=.
replace repet=0 if m5b_q16==1
replace repet=1 if m5b_q16==2
replace repet=2 if m5b_q16==3
replace repet=3 if m5b_q16==4

gen auto_avg=(autonomy+repet)/2
gen auto_rep=.
replace auto_rep=0 if auto_avg==0
replace auto_rep=1 if auto_avg>=0.5 & auto_avg<=1
replace auto_rep=2 if auto_avg>=1.5 & auto_avg<=2
replace auto_rep=3 if auto_avg>=2.5 & auto_avg<=3

tab auto_rep, m

**physical

gen physic=.
replace physic=0 if  m5b_q03==1
replace physic=1 if  m5b_q03>=2 & m5b_q03<=4
replace physic=2 if  m5b_q03>=5 & m5b_q03<=6
replace physic=3 if  m5b_q03>=7 & m5b_q03<=10


*OVERALL SKILLS-SKILLS USED AT WORK
gen read_dif=read-read_work
gen write_dif=write-read_work
gen num_dif=num-num_work
gen comp_dif=computer-comp_work
*************************************************************
*DUMMIES
********************************************************************

gen 	comp_wdummy=1 if m5b_q18==1
replace comp_wdummy=0 if m5b_q18==2

gen     comp_owdummy=1 if m5b_q30==1
replace comp_owdummy=0 if m5b_q30==2

gen		comp_dummy	=max(comp_wdummy, comp_owdummy)	


gen     read_wdummy=1 if  m5a_q04==1
replace read_wdummy=0 if m5a_q04==2
replace read_wdummy=1 if read_work>0 & read_work!=.
replace read_wdummy=0 if read_work==0

gen 	read_owdummy=0 if m5a_q07==6 		/*Question for workers who read at work*/
replace read_owdummy=1 if m5a_q07<=5 & m5a_q07!=.
replace read_owdummy=1 if m5a_q07==9 		/*Assumes ppl who answer "don't know" to length of material do 
													read outside work*/
replace read_owdummy=1 if m5a_q08==1 		/*Question for workers who do not read at work*/
replace read_owdummy=0 if m5a_q08==2
replace read_owdummy=1 if m5a_q21==1		 /*Question for those who haven't worked in last 12 months*/
replace read_owdummy=0 if m5a_q21==2
replace read_owdummy=0 if read_outside==0

gen     write_wdummy=1 if m5a_q12 ==1
replace write_wdummy=0 if m5a_q12 ==2
replace write_wdummy=0 if write_work==0

gen     write_owdummy=1 if m5a_q14 <=5 & m5a_q14 !=.
replace write_owdummy=1 if m5a_q14 ==9  		/*Assumes ppl who answer "don't know" do write outside work*/
replace write_owdummy=0 if m5a_q14 ==6
replace write_owdummy=1 if m5a_q16 ==1
replace write_owdummy=0 if m5a_q16 ==2
replace write_owdummy=1 if m5a_q25 ==1  	    /*Haven't worked in last 12 months*/
replace write_owdummy=0 if m5a_q25 ==2
replace write_owdummy=0 if write_outside==0

gen		num_wdummy	=1 if num_work!=. & num_work!=0
replace num_wdummy=0 if num_work==0
gen		num_owdummy	=1 if num_outside!=. & num_outside!=0
replace num_owdummy=0 if num_outside==0

gen		read_dummy	=max(read_wdummy, read_owdummy)	

gen		write_dummy	=max(write_wdummy, write_owdummy)	

gen		num_dummy	=max(num_wdummy, num_owdummy)	


*Label all dummies
label 	var	comp_wdummy	"Dummy for uses computer at work"
label 	var	comp_owdummy	"Dummy for uses computer outside of work"
label 	var	comp_dummy	"Dummy for uses computer overall"
label 	var	read_wdummy	"Dummy for reads at work"
label 	var	read_owdummy	"Dummy for reads outside of work"
label 	var	write_wdummy	"Dummy for writes at work"
label 	var	write_owdummy	"Dummy for writes outside of work"
label 	var	num_wdummy	"Dummy for numeracy at work"
label 	var	num_owdummy	"Dummy for numeracy outside of work"
label 	var	read_dummy	"Dummy for reads overall"
label 	var	write_dummy	"Dummy for writes overall"
label 	var	num_dummy	"Dummy for numeracy overall"


************************
********NON-COGNITIVE***
************************

replace m6b_q06=. if m6b_q06==92
mvdecode m6a*, mv(-44/-1=.)

if country=="Macedonia"{
	forvalues i=1(1)9 {
		rename m6a_q010`i' m6a_q01_0`i'
	}
	forvalues i=10(1)26{
		rename m6a_q01`i' m6a_q01_`i'
	}
	
mvdecode m6a*, mv(5/10=.)
}


if country=="Kenya" {
	forvalues i=1(1)9 {
		rename m6a_q10`i' m6a_q01_0`i'
	}
	forvalues i=10(1)26{
		rename m6a_q1`i' m6a_q01_`i'
	}
}

if country=="Kenya" { 
recode m6a_q01_01-m6a_q01_26 (4=1) (3=2) (2=3) (1=4)
}

*drop conscientiousness extraversion openness stability agreeableness grit decision decision hostile risk discount
**extraversion***
recode m6a_q01_04 (4=1) (3=2) (2=3) (1=4), gen( m6a_q01_04n )
egen extraversion_av=rowmean(m6a_q01_01 m6a_q01_04n m6a_q01_20)
label var extraversion_av "Extraversion (average of q01 q04 q20)"
tab extraversion_av, m

**Conscientiousness
recode  m6a_q01_12 (1=4) (2=3) (3=2) (4=1), gen( m6a_q01_12n )
egen conscientiousness_avg=rowmean(m6a_q01_02 m6a_q01_12n m6a_q01_17)
label var conscientiousness_av "Conscientiousness (average of q02 q12 q17)"
tab conscientiousness_av, m


**Openness
egen openness_av=rowmean(m6a_q01_03 m6a_q01_11 m6a_q01_14)
label var openness_av "Openness (average of q03 q11 q14)"
tab openness_av, m


**Emotional stability
recode  m6a_q01_10 m6a_q01_18 (1=4) (2=3) (3=2) (4=1), gen (m6a_q01_10n m6a_q01_18n)
egen stability_av=rowmean(m6a_q01_05 m6a_q01_10n m6a_q01_18n)
label var stability_av "Emotional Stability (average of q05 q10 q18)"
tab stability_av, m


**Agreeableness
egen agreeableness_av=rowmean(m6a_q01_09 m6a_q01_16 m6a_q01_19)
label var agreeableness_av "Agreeableness (average of q09 q16 q19)"
tab agreeableness_av,m

**Grit
egen grit_av=rowmean(m6a_q01_06 m6a_q01_08 m6a_q01_13)
label var grit_av "Grit (average of q06 q08 q13)"
tab grit_av, m 

**Decision making
egen decision_av=rowmean(m6a_q01_15 m6a_q01_21 m6a_q01_23 m6a_q01_24)
label var decision_av "Decision making (average of q15 q21 q23 q24)"
tab decision_av, m


**Hostile: 4- more likely to perceive people to be mean
egen hostile_av=rowmean(m6a_q01_07 m6a_q01_22)
label var hostile_av "Hostile Bias (average of q07 q22)"
tab hostile, m

**RISK AVERSION
gen risk=1 if m6b_q01==1 & m6b_q02==1
replace risk=2 if m6b_q01==1 & m6b_q02==2
replace risk=3 if m6b_q01==2 & m6b_q03==1
replace risk=4 if m6b_q01==2 & m6b_q03==2
label var risk  "Risk aversion" 
tab risk,m 

**discount
gen discount=1 if m6b_q04==1 & m6b_q05==1
replace discount=2 if m6b_q04==1 & m6b_q05==2
replace discount=3 if m6b_q04==2 & m6b_q07==1
replace discount=4 if m6b_q04==2 & m6b_q07==2
label var discount "Time preference" 
tab discount,m

drop m6a_q01_??n 

*LABEL VARIABLES
label 	var	read_work	"Length of material read at work score"
label 	var	read_outside	"Length of material read outside of work score"
label 	var	read	"Length of material read overall score"
label 	var	write_work	"Length of material written at work score"
label 	var	write_outside	"Length of material written outside of work score"
label 	var	write	"Length of material written overall score"
label 	var	num_work	"Numeracy at work score"
label 	var	num_outside	"Numeracy outside of work score"
label 	var	num	"Numeracy overall score"
label 	var	interpers_ex	"Contact with people outside of work score"
label 	var	present	"Makes presentations at work"
label 	var	supervise	"Supervises others at work"
label 	var	comp_work	"Frequency of computer use at work score"
label 	var	comp_outside	"Frequency of computer use outside of work score"
label 	var	computer	"Frequency of computer use overall score"
label 	var	computertype	"Type of software use at work score"
label 	var	drive	"Drives a vehicle at work"
label 	var	repair	"Repairs or maintains electronic equipment at work" 
label 	var	operate	"Operates heavy machinery or industrial equipment at work"
label 	var	think	"Frequency of tasks involving at least 30 minutes of thinking score"
label 	var	learn	"Frequency of work requiring learning new things score"
label 	var	cogchall_avg	"Average of frequency of thinking and learning tasks scores"
label 	var	cogchall	"Frequency of thinking and learning new things score"
label 	var	autonomy	"Autonomy at work score"
label 	var	repet	"Repetitiveness at work score"
label 	var	auto_avg	"Average of autonomy and repetitiveness at work scores"
label 	var	auto_rep	"Autonomy and repetitiveness at work score"
label 	var	physic	"Lift heavy items at work score"
label 	var	read_dif	"Difference between overall reading and reading at work score"
label 	var	write_dif	"Difference between overall writing and writing at work score"
label 	var	num_dif	"Difference between overall numeracy and numeracy at work score"
label 	var	comp_dif	"Difference between overall computer use and computer use at work score"

label define intensity 0 "skill not used" 1 "low" 2 "medium" 3 "high"
foreach var of varlist read_work read_outside read write_work write_outside write num_work num_outside num comp_work comp_outside computer {
	lab values `var' intensity
}
	
	compress
	sort cluster hhn
	save "$pathworkingdata/STEP `country'_working.dta", replace
}


**************************************************************************** END OF STEP DO-FILE 3 ******************************************************************
