* STEP Skills Measurement Program
* Do-File: Data Check Template
/* This template was modified on a country by country basis to check the quality of the 
data received from the data collection firms

The check revised for:
	- Legal skips
	- Labels
	- Consistency
	- Range
	- Randomization
*/

clear all
set mem 1000M
set more off
estimates clear

********************
* General Comments *
********************

/* Depending on the country, we merged the individual respondent data with the household roster */
* Merge Main data with Household. 

use $in/HH_ROSTER_S10.dta, replace
sort hhn cluster 
save, replace 

* Needed to create id that matches main id
drop zero id_m
gen zero=0 if hhn<10 & hhn!=.
egen id1=concat(cluster zero hhn) if hhn<10
egen id2=concat(cluster hhn) if hhn>=10
destring id1 id2, replace

egen id_m=rowmax(id1 id2)
drop id1 id2
order country id_m cluster hhn 

sort hhn cluster id_m
save, replace

use $in/FINAL_INDIVIDUAL_DATA_S10.dta, replace 
sort hhn cluster 

* Needed to create id that matches main id
*drop zero id_m
gen zero=0 if hhn<10 & hhn!=.
egen id1=concat(cluster zero hhn) if hhn<10
egen id2=concat(cluster hhn) if hhn>=10
destring id1 id2, replace

egen id_m=rowmax(id1 id2)
drop id1 id2
order country id_m cluster hhn 

* Cannot create the Elegido var due to missing id_select var

sort hhn cluster id_m
save, replace

merge hhn cluster id_m using "$in/HH_ROSTER_S10.dta"
tab _merge

drop if hh_listing_n==.

keep if _merge==3
drop _merge zero


gen elegido=.
replace elegido=1 if idcode==id_selected
replace elegido=0 if elegido==.

tab elegido, m 

order country id_m cluster hhn idcode elegido
order m1a_q01-m1a_q20, before(m1b_q01)
order m1c_a-m4b_q08_3, after(m1b_q21_10)
order ln_1-m4b_q12_3, after(m4a_q31_3)

sort hhn cluster id_m

save "$in/`country'.dta", replace
*/

u "$in/`country'.dta", replace
*****************
* RANDOM NUMBERS *
******************

* Check random numbers: they should all be different and should be between 1-15

preserve

gen not1to15=.
gen idn=.
 
forvalues x=1/15 {
	replace not1to15=1 if N`x'>15 | N`x'<1 | N`x'==.
	forvalues y=1/15 {
		if `y'>`x' {
			replace idn=1 if N`x'==N`y'
		}
	}
}
tab not1 if elegido==1
tab idn  if elegido==1
list cluster hhn N* idn if (not==1 | idn==1) & elegido==1

restore

* all random numbers fall between 1-15 and are different

**********************
* HOUSEHOLD : ROSTER *
**********************

* Anyone between 15 and 64? Check of date of birth. 

gen agecheck=2013-m1a_q05y
su cluster hhn m1a_q04 m1a_q05m m1a_q05y agecheck
su cluster hhn m1a_q04 m1a_q05m m1a_q05y agecheck if elegido==1

list cluster hhn idcode id_selected m1a_q04 m1a_q05m m1a_q05y agecheck if ((m1a_q05y>0 & m1a_q05y<1910) | m1a_q04>64) & elegido==1, nolabel


*list id cluster hhn idcode m1a_q04 m1a_q05m m1a_q05y agecheck if (m1a_q05y>0 & m1a_q05y<1910) | m1a_q04>64 & elegido==1, nolabel

*are IDs of respondents missing?
list cluster hhn m11_q07 m11_q03_id1 if missing(m11_q03_id1) & elegido==1, nolabel


* are IDs of respondents one of the ID_code? 
by cluster hhn, sort: egen test=max(idcode)
list cluster hhn idcode m11_q03_id1 if m11_q03_id1>test & !missing(m11_q03_id1)


duplicates list cluster hhn idcode 
/* Check for duplicates*/

gen hh_m=1 if m1a_q03==1 & m1a_q02==1
replace hh_m=2 if m1a_q03==1 & m1a_q02==2

gen sp_m=1 if m1a_q03==2 & m1a_q02==1
replace sp_m=2 if m1a_q03==2 & m1a_q02==2

egen aux1=max(hh_m), by(id_m)
egen aux2=max(sp_m), by(id_m)

* Same sex marriage 
egen same_sm=diff(aux1 aux2)
replace same_sm=. if missing(aux1) | missing(aux2)
drop aux*
list id_m cluster hhn idcode m1a_q02 m1a_q03 same_sm if same_sm==0

* Multiple head of households per households

gen aux=1 if m1a_q03==1 
egen multi_h=count(aux), by(id_m)
drop aux 

list cluster hhn idcode m1a_q02 m1a_q03 multi_h if multi_h>1

misstable summarize country cluster hhn idcode region dist ea m1a* , all

* count number of idcodes recorded vs. number of people
gen aux=1 if m1a_q02!=.a
by cluster hhn, sort: egen npers=count(aux)
by cluster hhn, sort: egen nidcode=count(idcode)
sort cluster hhn idcode
list cluster hhn npers nidcode idcode if (npers~=nidcode) & aux<=.

**********************
* MODULE 1A***********
**********************

	*check missing values and ranges from Q1 to Q5
	misstable summarize idcode m1a_q02 m1a_q03 m1a_q04 m1a_q05m m1a_q05y, all



	*check birth year out of range 
	list cluster hhn idcode m1a_q02 m1a_q03 m1a_q04 m1a_q05m m1a_q05y  if (m1a_q05y>2013 |m1a_q05y<1910) & !missing(m1a_q05m), nolabel  

*check age out of range
list cluster hhn idcode m1a_q02 m1a_q03 m1a_q04 m1a_q05m m1a_q05y  if (m1a_q04>100 |m1a_q04<0) & !missing(m1a_q04,agecheck), nolabel  
/* check observations with more than 100 years of age.*/


*check consistency in age
list cluster hhn idcode m1a_q04 m1a_q05m m1a_q05y agecheck if abs(2013-m1a_q05y-m1a_q04)>1 & !missing(agecheck), nolabel

*check consistency in age and question 6, and 18

list cluster hhn idcode m1a_q04 m1a_q05m m1a_q05y m1a_q18 if m1a_q18==1 & (m1a_q04<15 |m1a_q04>64)
list cluster hhn idcode m1a_q04 m1a_q05m m1a_q05y if m1a_q06==1 & (m1a_q04<6)

*check skips in M1A
foreach var of varlist m1a_q07 m1a_q08 m1a_q09 m1a_q10 m1a_q11 m1a_q12 m1a_q13 m1a_q14 m1a_q15 m1a_q16 m1a_q17 m1a_q18 m1a_q19 m1a_q20 {
	recode `var' (.=.b) if m1a_q06==2
	list cluster hhn idcode m1a_q07 m1a_q08 m1a_q09 m1a_q10 m1a_q11 m1a_q12 m1a_q13 m1a_q14 m1a_q15 m1a_q16 m1a_q17 m1a_q18 m1a_q19 m1a_q20 if m1a_q06==0 & !missing(`var'), nolabel
}
foreach var of varlist m1a_q08  m1a_q09 {
	recode `var' (.=.b) if m1a_q07==2 | m1a_q07==-9
	list cluster hhn idcode m1a_q07 m1a_q08 m1a_q09 if (m1a_q07==2 | m1a_q07==-9) & !missing(`var'), nolabel
}

foreach var of varlist m1a_q10 m1a_q11 {
	recode `var' (.=.b) if m1a_q09>=3 & m1a_q09<=8 
	list cluster hhn idcode m1a_q07 m1a_q08 m1a_q09 m1a_q10 m1a_q11 m1a_q12 if m1a_q09>=3 & m1a_q09<=8 & !missing(`var')
}
list cluster hhn idcode m1a_q09 m1a_q10 m1a_q11 if (m1a_q10==. | m1a_q11==.) & (m1a_q09<=2 | m1a_q09==.b), nolabel	


foreach var of varlist m1a_q13 m1a_q14 m1a_q15 m1a_q16 m1a_q17 m1a_q18 m1a_q19 m1a_q20 {
	recode `var' (.=.b) if m1a_q12 ==2
	list cluster hhn idcode m1a_q12 m1a_q13 m1a_q14 m1a_q15 m1a_q16 m1a_q17 m1a_q18 m1a_q19 m1a_q20  if m1a_q12 ==0 & !missing(`var')
}
list cluster hhn idcode m1a_q12 m1a_q13 if m1a_q13==. & m1a_q12==1, nolabel	



foreach var of varlist m1a_q15 m1a_q16 {
	recode `var'(.=.b) if m1a_q14==1
	list cluster hhn idcode m1a_q14 `var' if m1a_q14==1 & !missing(`var')
}

foreach var of varlist m1a_q16 m1a_q17 {
	recode `var'(.=.b) if m1a_q15==1
	list cluster hhn idcode m1a_q15 `var' if m1a_q15==1 & !missing(`var')
}
list cluster hhn idcode m1a_q15 m1a_q16 if m1a_q16==. & m1a_q15==2, nolabel	


recode m1a_q17 (.=.b) if m1a_q16<7	
recode m1a_q17 (.=.b) if m1a_q14==2
list cluster hhn idcode m1a_q14 m1a_q17 if m1a_q14==2 & !missing(m1a_q17)

list cluster hhn idcode m1a_q14 m1a_q17 if m1a_q17==. & m1a_q14==1, nolabel	

recode m1a_q19 m1a_q20  (.=.b) if m1a_q18==2
list cluster hhn idcode m1a_q18 m1a_q19 m1a_q20 if  m1a_q18==2 & (!missing(m1a_q19)| !missing(m1a_q20))
	
recode  m1a_q20  (.=.b) if m1a_q19==2
list cluster hhn idcode m1a_q18 m1a_q19 m1a_q20 if  m1a_q19==2 & (!missing(m1a_q20))
	
* Generating sequential numbers
bysort cluster hhn: egen sequential=seq() if inrange(m1a_q04,15,64) & inrange(m1a_q19,1,1), f(1) t(20)
* Gen sequential error indicator (==1 if different)
egen seqerror=diff(m1a_q20 sequential) if !missing(m1a_q20,sequential)
* Gen sequential error indicator by household
bysort cluster hhn: egen seqerror1=max(seqerror)

tab seqerror1 if m1a_q03==1
list cluster hhn seqerror1 if seqerror1==1 & m1a_q03==1

	
misstable summarize m1a*, all

**********************
* MODULE 1C***********
**********************

* does Number A equals to the number of persons qualified from Q20?
by cluster hhn, sort: egen neligible=count(m1a_q20)
by cluster hhn, sort: egen numA=mean(m1c_a)
by cluster hhn, sort: egen numB=mean(m1c_b)
sort cluster hhn idcode
list cluster hhn idcode m1a_q04 m1a_q18 m1a_q19 m1a_q20 m1c_a m1c_b  neligible  if  numA~=neligible & numA!=., nolabel

* is Number B less than or equal to number A? is Number B the greatest?
list cluster hhn numA numB if numA<numB

preserve

drop if N1==.
forvalues x=1/15 {
gen numb=0
replace numb=`x' if  m1c_b==N`x'
	forvalues y=1/15 {
	list cluster hhn m1c_a  m1c_b N* numb if `y'<numb & N`y'<=m1c_a
	}
drop numb
}


restore

/* number B is less than or equal to A in all cases; incorrect selection of random numbers*/

* does all observations with yes in m1a_q18 and m1a_q19 have non missing in numA and numB
list cluster hhn numA numB m1a_q18 m1a_q19 m1c_a m1c_b m1a_q20 m11_q07 if missing(numA, numB) & m1a_q18==1 & m1a_q19==1, nolab

* is Number B equal to the sequential number?

list cluster hhn idcode m1a_q20 m1c_a  m1c_b neligible if  m1c_b~=m1a_q20 &!missing(m1c_b)


* does elegido reflect number B? yes*/
list cluster hhn idcode m1a_q20 m1c_a  m1c_b neligible elegido if numB~=m1a_q20 & elegido==1

/* does elegido has the correct id_code? */
list cluster hhn idcode m1a_q20 m1c_a m1c_b if id_selected~=idcode & elegido==1 

* check age and gender distribution of the respondant selected

tab m1a_q02 if elegido==1
histogram m1a_q04 if elegido==1, by(m1a_q02)
mean m1a_q04, over(m1a_q02 )



**********************
* MODULE 1B***********
**********************
preserve 
keep if m1b_q01<.
keep if m1a_q03==1

recode m1b_q09 (.=.b) if m1b_q08==16 | m1b_q08==17
list cluster hhn m1b_q08 m1b_q09 if (m1b_q08==16 | m1b_q08==17) & !missing(m1b_q09)

foreach var in m1b_q11 {
recode `var' (.=.b) if m1b_q10==6
list cluster hhn m1b_q10 m1b_q11 m1b_q12 if m1b_q10==6 & !missing(m1b_q10, m1b_q11)
}

recode m1b_q14 (.=.b) if (m1b_q13==5 | m1b_q13==7)
list cluster hhn m1b_q13 m1b_q14 if (m1b_q13==5 | m1b_q13==7) & !missing(m1b_q14), nolabel


recode m1b_q17_1 m1b_q17_2 m1b_q17_3 m1b_q17_4 m1b_q17_5 m1b_q17_6 (.=.b) if m1b_q16_7==2
list cluster hhn m1b_q16_7 m1b_q17_* if m1b_q16_7==2 & !missing(m1b_q17_1-m1b_q17_6)

recode m1b_q01 (.=.a)

foreach var of varlist  m1b_q02 m1b_q03 m1b_q04 m1b_q05 m1b_q06-m1b_q08 m1b_q09 m1b_q10 m1b_q11 m1b_q12 m1b_q13 m1b_q14-m1b_q21_10{
	recode `var' (.=.a) if m1b_q01==.a
	list cluster hhn idcode elegido `var' m11_q07 if `var'==. 
}

* range and missing values
misstable summarize m1b_*, all



*other
list cluster hhn m1b_q01 m1b_q01_other if m1b_q01==9 & m1b_q01_other==""
list cluster hhn m1b_q02 m1b_q02_other if m1b_q02==11 & m1b_q02_other==""
list cluster hhn m1b_q03 m1b_q03_other if m1b_q03==10 & m1b_q03_other==""
list cluster hhn m1b_q04 m1b_q04_other if m1b_q04==19 & m1b_q04_other==""
list cluster hhn m1b_q05 m1b_q05_other if m1b_q05==9 & m1b_q05_other==""
list cluster hhn m1b_q08 m1b_q08_other if m1b_q08==19 & m1b_q08_other==""
list cluster hhn m1b_q10 m1b_q10_other if m1b_q10==7 & m1b_q10_other==""
list cluster hhn m1b_q11 m1b_q11_other if m1b_q11==19 & m1b_q11_other==""
list cluster hhn m1b_q12 m1b_q12_other if m1b_q12==19 & m1b_q12_other==""
list cluster hhn m1b_q13 m1b_q13_other if m1b_q13==19 & m1b_q13_other==""

restore 

**********************
* MODULE 2************                                                                                 ***********
**********************
preserve
keep if elegido==1
keep if m11_q07>40
list cluster hhn idcode id_selected m2_q01 m2_q02 if missing(m2_q01, m2_q02)

tab m2_q02, m nolab

*checking skips 

foreach var of varlist m2_q03_1 m2_q03_2 m2_q04 m2_q05 m2_q06 {
	recode `var' (.=.b) if m2_q02==1 
	list cluster hhn idcode m2_q02 `var' if m2_q02==1 & !missing(`var')
}
list cluster hhn idcode m2_q02 m2_q03_1 m2_q03_2 m2_q04  if m2_q03_1==. 

foreach var of varlist m2_q06 m2_q07 m2_q08al m2_q08ag m2_q08b m2_q09_1 m2_q09_2 m2_q10 m2_q12 m2_q13 m2_q14 m2_q15 m2_q16 m2_q17 m2_q18 m2_q19 m2_q20l m2_q20g m2_q21 m2_q22 m2_q23_1 m2_q23_2 m2_q24g m2_q24l m2_q25 m2_q26 m2_q27 m2_q28 m2_q29 m2_q30 m2_q31 m2_q33_code m2_q34 m2_q35_1 m2_q35_2 m2_q36{
	recode `var' (.=.b) if m2_q05==2
	list cluster hhn idcode m2_q05 `var' if m2_q05==2 & !missing(`var')
}

foreach var of varlist m2_q07 m2_q08al m2_q08ag m2_q08b m2_q09_1 m2_q09_2 m2_q10 m2_q12 m2_q13 m2_q14 m2_q15 m2_q16 m2_q17 m2_q18 m2_q19 m2_q20l m2_q20g m2_q21 m2_q22 m2_q23_1 m2_q23_2 m2_q24g m2_q24l m2_q25 m2_q26 m2_q27 m2_q28 m2_q29 m2_q30 m2_q31 m2_q33_code m2_q34 m2_q35_1 m2_q35_2 m2_q36{
	recode `var' (.=.b) if m2_q06<.
	list cluster hhn idcode m2_q05 m2_q06 `var' if m2_q06<. & !missing(`var')
}

list cluster hhn idcode m2_q02 m2_q05 m2_q06 m2_q07 if m2_q07==., nolab


foreach var of varlist m2_q08b m2_q09_1 m2_q09_2  {
	recode `var' (.=.b) if m2_q08al==1
	list cluster hhn idcode m2_q08al `var' if m2_q08al==1 & !missing(`var')
}

foreach var of varlist m2_q09_1 m2_q09_2  {
	recode `var' (.=.b) if m2_q08b==1
	list cluster hhn idcode m2_q08b `var' if m2_q08b==1 & !missing(`var')
}

foreach var of varlist m2_q09_1 m2_q09_2 m2_q10{
	recode `var' (.=.b) if (m2_q08b==2 | m2_q08b==3 | m2_q08b==6) 
	list cluster hhn idcode m2_q08b `var' if (m2_q08b==2 | m2_q08b==3 | m2_q08b==6)  & !missing(`var'), nolabel
}

recode m2_q09_2 (.=.c) if m2_q09_1<.

recode m2_q10 (.=.b) if m2_q09_1<=24 | m2_q09_2<=24
list cluster hhn idcode m2_q08al m2_q08b m2_q09_1 m2_q09_2 m2_q10 m2_q12 if m2_q10==. | m2_q12==., nolabel

recode m2_q13 (.=.b) if m2_q12==5
list cluster hhn idcode m2_q12 m2_q13  if m2_q12==5 & !missing(m2_q13)

list cluster hhn idcode m2_q12 m2_q13 m2_q14  if m2_q13==. | m2_q14==., nolabel

foreach var of varlist m2_q15 m2_q16 {
	recode `var' (.=.b) if m2_q14==2
	list cluster hhn idcode m2_q14 `var' if m2_q14==2 & !missing(`var')
}

list cluster hhn idcode m2_q14 m2_q15 m2_q16  if m2_q15==. | m2_q16==., nolabel

recode m2_q18 (.=.b) if m2_q17==2
list cluster hhn idcode m2_q17 m2_q18  if m2_q17==2 & !missing(m2_q18)

list cluster hhn idcode m2_q17 m2_q18 if m2_q17==. | m2_q18==., nolabel


foreach var of varlist m2_q20l m2_q20g m2_q21 {
	recode `var' (.=.b) if m2_q19==2
	list cluster hhn idcode m2_q19 `var' if m2_q19==2 & !missing(`var')
}

list cluster hhn idcode m2_q19-m2_q20g if m2_q19==. | m2_q20l==. | m2_q20g==., nolabel

recode m2_q21 (.=.b) if m2_q20l==99
list cluster hhn idcode m2_q20l m2_q21  if m2_q20l==99 & !missing(m2_q21)



foreach var of varlist m2_q21 m2_q22 m2_q23_1 m2_q23_2 m2_q24g m2_q24l m2_q25 m2_q26 m2_q27 m2_q28 m2_q29 m2_q30 m2_q31 m2_q33_code {
	recode `var' (.=.b) if m2_q20l==2 | m2_q20l==6
	list cluster hhn idcode m2_q20l `var' if (m2_q20l==2 | m2_q20l==6) & !missing(`var')
}



foreach var of varlist m2_q22 m2_q23_1 m2_q23_2 m2_q24g m2_q24l m2_q25 m2_q26 m2_q27 m2_q28 m2_q29 m2_q30 m2_q31 m2_q33_code {
	recode `var' (.=.b) if m2_q21<.
	list cluster hhn idcode m2_q21 `var' if m2_q21<. & !missing(`var')
}

list cluster hhn idcode m2_q20l m2_q21 m2_q22 if m2_q21==. | m2_q22==., nolabel

foreach var of varlist m2_q23_1 m2_q23_2 m2_q24l m2_q24g m2_q25 {
	recode `var' (.=.b) if m2_q22==2 
	list cluster hhn idcode m2_q22 `var' if m2_q22==2 & !missing(`var')
}

list cluster hhn idcode m2_q22 m2_q23_1 m2_q23_2 m2_q24* if m2_q22==. | (m2_q23_1==. & m2_q23_2==.) | m2_q24l==. | m2_q24g==., nolabel


foreach var of varlist m2_q25 {
	recode `var' (.=.b) if m2_q24l==2 | m2_q24l==3 | m2_q24l==6
	list cluster hhn idcode m2_q24l `var' if (m2_q24l==2 | m2_q24l==3 | m2_q24l==6) & !missing(`var')
}


list cluster hhn idcode m2_q25 m2_q26 m2_q27 if m2_q25==. | m2_q26==. | m2_q27==., nolabel


recode m2_q28 (.=.b) if m2_q27==1
list cluster hhn idcode m2_q27 m2_q28 if m2_q27==1 & !missing(m2_q28)

list cluster hhn idcode m2_q27 m2_q28 if m2_q27==. | m2_q28==., nolab

foreach var of varlist m2_q29 m2_q30 m2_q31 m2_q33_code {
	recode `var' (.=.b) if m2_q28<.
	list cluster hhn idcode m2_q28 `var' if m2_q28<. & !missing(`var')
}
list cluster hhn idcode m2_q27 m2_q29 m2_q31 m2_q33_code if m2_q29==. | m2_q30==. | m2_q31==. | m2_q33_code==., nolabel

foreach var of varlist m2_q35_1 m2_q35_2 m2_q36 {
	recode `var' (.=.b) if m2_q34==2
	list cluster hhn idcode m2_q34 `var' if m2_q34==2 & !missing(`var')
}

list cluster hhn idcode  m2_q34 m2_q35_1 m2_q35_2 m2_q36 if m2_q34==. | (m2_q35_1==. & m2_q35_2==.) | m2_q36==., nolabel


recode m2_q38_1 m2_q38_2(.=.b) if m2_q37==2
list cluster hhn idcode m2_q37 m2_q38_* if m2_q37==2 & !missing(m2_q38_1,m2_q38_2)

list cluster hhn idcode m2_q37 m2_q38_* if m2_q37==. | (m2_q38_1==. & m2_q38_2==.), nolabel

foreach var of varlist m2_q40_code1 m2_q40_mths1 m2_q40_3 m2_q40_code2 m2_q40_mths2 m2_q40_6 {
	recode `var' (.=.b) if m2_q39==2
	list cluster hhn idcode m2_q39 `var' if m2_q39==2 & !missing(`var')
}

list cluster hhn idcode m2_q39 m2_q40_* if (m2_q40_code1==. & m2_q40_code2==.), nolabel

foreach var of varlist m2_q42 m2_q43 m2_q44 {
	recode `var' (.=.b) if m2_q41==2
	list cluster hhn idcode m2_q41 `var' if m2_q41==2 & !missing(`var')
}

list cluster hhn idcode m2_q41 m2_q42 m2_q43 m2_q44 if m2_q41==. | m2_q42==. | m2_q43==. | m2_q44==., nolabel

recode m2_q40_code2 m2_q40_mths2 m2_q40_6 (.=.c) if m2_q40_code1!=. 
misstable summarize m2_*, all

*others

list cluster hhn idcode m2_q03_1 m2_q03_2 m2_q03_other if (m2_q03_1==19 | m2_q03_2==19) & m2_q03_other=="", nolabel

list cluster hhn idcode m2_q09_1 m2_q09_2 m2_q09_other if (m2_q09_1==24 | m2_q09_2==24) & m2_q09_other=="", nolabel


list cluster hhn idcode m2_q12 m2_q12_other if m2_q12==9 & m2_q12_other==""
list cluster hhn idcode m2_q13 m2_q13_other if m2_q13==9 & m2_q13_other==""
list cluster hhn idcode m2_q16 m2_q16_other if (m2_q16==24) & m2_q16_other==""
list cluster hhn idcode m2_q18 m2_q18_other if (m2_q18==24) & m2_q18_other==""
list cluster hhn idcode m2_q21 m2_q21_other if (m2_q21==24) & m2_q21_other==""
list cluster hhn idcode m2_q25 m2_q25_other if (m2_q25==24) & m2_q25_other==""
list cluster hhn idcode m2_q30 m2_q30_other if (m2_q30==3) & m2_q30_other==""
list cluster hhn idcode m2_q35_1 m2_q35_2 m2_q35_other if (m2_q35_1==99 | m2_q35_2==99) & m2_q35_other==""
list cluster hhn idcode m2_q38_1 m2_q38_2 m2_q38_other if (m2_q38_1==59 | m2_q38_2==59) & m2_q38_other==""


*consistency 
 
* out of range
*age starting first grade
tab m2_q07, m
*age out of formal education
tab m2_q26, m 
*duration of apprenticship
tab m2_q40_mths1, m
tab m2_q40_mths2, m

restore

**********************
* MODULE 3* **********                                                                                 ***********
**********************
*skip

recode m3_q06(.=.b) if m3_q05==2
list cluster hhn idcode m3_q05 m3_q06 if m3_q05==2& !missing(m3_q06)

*other
list cluster hhn idcode m3_q07_other if m3_q07==5 & m3_q07_other=="" & elegido==1

misstable summarize m3_* if elegido==1, all

*out of range
list cluster hhn idcode m3_q04 if m3_q04>28 & !missing(m3_q04)
list cluster hhn idcode m3_q06 if m3_q06>28 & !missing(m3_q06)

**********************
* MODULE 4A***********                                                                                 
**********************

*skips
preserve
keep if elegido==1

keep if m11_q07>53

foreach var of varlist m4a_q02  m4a_q03  m4a_q04  m4a_q05  m4a_q06  m4a_q07  m4a_q08  m4a_q09  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  m4a_q16  m4a_q17  m4a_q18  m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3 {
	recode `var' (.=.b) if  m4a_q01==1
	list cluster hhn idcode m4a_q01 `var' if m4a_q01==1 & !missing(`var'), nolabel
	}

list cluster hhn idcode m4a_q01 if m4a_q01==., nolabel

foreach var of varlist m4a_q03  m4a_q04  m4a_q05  m4a_q06  m4a_q07  m4a_q08  m4a_q09  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  m4a_q16  m4a_q17  m4a_q18  m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3  {
	recode `var' (.=.b) if  m4a_q02==1
	list cluster hhn idcode m4a_q02 `var' if m4a_q02==1 & !missing(`var')
	}
	
foreach var of varlist m4a_q04  m4a_q05  m4a_q06  m4a_q07  m4a_q08  m4a_q09  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  m4a_q16  m4a_q17  m4a_q18  m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3 {
	recode `var' (.=.b) if  m4a_q03==1
	list cluster hhn idcode m4a_q03 `var' if m4a_q03==1 & !missing(`var')
	}
	

foreach var of varlist m4a_q05  m4a_q06  m4a_q07  m4a_q08  m4a_q09  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  m4a_q16  m4a_q17  m4a_q18  m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3 {
	recode `var' (.=.b) if  m4a_q04==1
	list cluster hhn idcode m4a_q04 `var' if m4a_q04==1 & !missing(`var')
	}
	

list cluster hhn idcode m4a_q01 m4a_q02 m4a_q03 m4a_q04 if m4a_q01==. | m4a_q02==. | m4a_q03==. | m4a_q04==., nolabel

recode m4a_q06 (.=.b)if m4a_q05==2
list cluster hhn idcode m4a_q05 m4a_q06 if m4a_q05==2  & !missing(m4a_q06)


foreach var of varlist m4a_q07  m4a_q08  m4a_q09  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  m4a_q16  m4a_q17  m4a_q18  m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3 {
	recode `var' (.=.b) if m4a_q06==1
	list cluster hhn idcode m4a_q06 `var' if m4a_q06==1 & !missing(`var')
	}
	
foreach var of varlist m4a_q08  m4a_q09 {
	recode `var' (.=.b) if m4a_q07==1
	list cluster hhn idcode  m4a_q07 `var' if  m4a_q07==1 & !missing(`var')
	}

foreach var of varlist m4a_q10_01-m4a_q10_09  m4a_q09 {
	recode `var' (.=.b) if m4a_q08==1
	list cluster hhn idcode  m4a_q08 `var' if  m4a_q08==1 & !missing(`var')
}


foreach var of varlist m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  m4a_q13  m4a_q14  m4a_q15  {
	recode `var' (.=.b) if m4a_q09>=1 & m4a_q09<=9
	list cluster hhn idcode m4a_q09 `var' if m4a_q09>=1 & m4a_q09<=9 & !missing(`var')
}

foreach var of varlist  m4a_q10_01  m4a_q10_02  m4a_q10_03  m4a_q10_04  m4a_q10_05  m4a_q10_06  m4a_q10_07  m4a_q10_08  m4a_q10_09  m4a_q11  m4a_q12  {
	recode `var' (.=.b) if m4a_q09>=11 & m4a_q09<=15
	list cluster hhn idcode m4a_q09 `var' if m4a_q09>=11 & m4a_q09<=15 & !missing(`var')
}

recode m4a_q15 (.=.b) if m4a_q14==2
list cluster hhn idcode m4a_q14 m4a_q15 if m4a_q14==2 & !missing( m4a_q15 )


foreach var of varlist m4a_q17  m4a_q18 {
	recode `var' (.=.b) if m4a_q16==1
	list cluster hhn idcode m4a_q16 `var' if m4a_q16==1 & !missing(`var')
}

list cluster hhn idcode m4a_q16 if m4a_q16>2 & !missing(m4a_q16), nolabel

foreach var of varlist m4a_q18 {
	recode `var' (.=.b) if m4a_q17==1
	list cluster hhn idcode m4a_q17 `var' if m4a_q17==1 & !missing(`var')
	}

foreach var of varlist m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29 {
	recode `var' (.=.b) if m4a_q18==1 
	list cluster hhn idcode m4a_q18 `var' if m4a_q18==1 & !missing(`var')
}

foreach var of varlist m4a_q19_mth  m4a_q19_y  m4a_q20  m4a_q22_y  m4a_q22_m  m4a_q23  m4a_q24  m4a_q25  m4a_q26  m4a_q27  m4a_q28  m4a_q29  m4a_q30_1  m4a_q30_2  m4a_q30_3 {
	recode `var' (.=.b) if m4a_q18==2 | m4a_q18==-9
	list cluster hhn idcode m4a_q18 `var' if (m4a_q18==2 | m4a_q18==-9) &!missing(`var')
}


foreach var of varlist m4a_q26  m4a_q27  m4a_q28 {
	recode `var' (.=.b) if m4a_q25==1 |m4a_q25==3| m4a_q25==4
	list cluster hhn idcode m4a_q25 `var' if (m4a_q25==1 |m4a_q25==3| m4a_q25==4) & !missing(`var')
}

foreach var of varlist  m4a_q27  m4a_q28 {
	recode `var' (.=.b) if m4a_q26==2
	list cluster hhn idcode m4a_q26 `var' if m4a_q26==2 & !missing(`var')
}

foreach var of varlist m4a_q30_1  m4a_q30_2  m4a_q30_3{
	recode `var' (.=.b) if  m4a_q29==2
	list cluster hhn idcode m4a_q29 `var' if   m4a_q29==2 & !missing(`var')
}


*Range
list cluster hhn idcode m4a_q11 if m4a_q11>24 &  m4a_q11~=88 & !missing(m4a_q11)
list cluster hhn idcode m4a_q11 if m4a_q11>90 & !missing(m4a_q11)

list cluster hhn idcode m4a_q19_mth if  m4a_q19_mth>12 & m4a_q19_mth~=99 & !missing( m4a_q19_mth)

list cluster hhn idcode m4a_q22_m if m4a_q22_m>12 & !missing(m4a_q22_m)

*string variables
list cluster hhn idcode m4a_q09 m4a_q09_other if m4a_q09==15 & m4a_q09_other==""
list cluster hhn idcode m4a_q10_09 m4a_q10_other if m4a_q10_09==1 & m4a_q10_other==""
list cluster hhn idcode m4a_q15 m4a_q15_other if m4a_q15==7 & m4a_q15_other==""
list cluster hhn idcode m4a_q24 m4a_q24_other if m4a_q24==11 & m4a_q24_other==""
list cluster hhn idcode m4a_q25 m4a_q25_other if  m4a_q25==4 & m4a_q25_other==""
list cluster hhn idcode m4a_q28 m4a_q28_other if m4a_q28==11 & m4a_q28_other==""

misstable summarize m4a*, all

*************
* Module 4b *
*************

*skips in 4b
foreach var of varlist m4b_q01_* m4b_q03_* m4b_q04_* m4b_q05_* m4b_q06_* m4b_q07_* m4b_q08_* m4b_q09 m4b_q10 m4b_q11_1 m4b_q11_2 m4b_q11_3 m4c_q01_code m4c_q02 m4c_q03_m m4c_q03_y m4c_q04 m4c_q05_m m4c_q05_y m4c_q06 m4c_q07 m4c_q08 m4c_q09_amnt m4c_q09_period m4c_q10 m4c_q11 m4c_q12 m4c_q13 m4c_q14 m4c_q15 m4c_q16 m4c_q17 m4c_q18 m4c_q19 m4c_q20 m4c_q21 m4c_q22 m4c_q23 m4c_q24 m4c_q25 m4c_q26 m4c_q27 m4c_q28 m4c_q29 m4c_q30_* m4c_q31 m4c_q32 m4c_q33 m4c_q34 m4c_q35 m4c_q36{
	recode `var' (.=.b) if m4a_q18==1|  m4a_q18==2 | m4a_q18==-9
	list cluster hhn idcode m4a_q18 if (m4a_q18==1|  m4a_q18==2 | m4a_q18==-9) &!missing(`var')
	recode `var' (.=.b) if m4a_q29==1 | m4a_q29==2
	list cluster hhn idcode m4a_q29 if (m4a_q29==1 | m4a_q29==2) &!missing(`var')
	recode `var' (.=.b) if m4a_q30_1!=. | m4a_q30_2!=. | m4a_q30_3!=.
	list cluster hhn idcode m4a_q30_* if  (m4a_q30_1!=. | m4a_q30_2!=. | m4a_q30_3!=. ) & !missing(`var')
}
 

 foreach var of varlist m4b_q11_* {
	recode `var' (.=.b) if  m4b_q10==2
	list cluster hhn idcode m4b_q10 `var' if  m4b_q10==2 & !missing(`var')
}

misstable summarize m4b_q01_* m4b_q03_* m4b_q04_*, all

misstable summarize m4b_q05_* m4b_q06_* m4b_q07_* m4b_q08_*, all

foreach var of varlist m4b_q05_*{
di "`var'"
list cluster hhn idcode `var' if `var'>7 & !missing(`var')
}

foreach var of varlist m4b_q06_*{
	di "`var'"
	list cluster hhn idcode `var' if `var'>24 & !missing(`var')
}

forvalues i=1(1)3{
	gen m4b_q07_`i'_check=m4b_q05_`i'*m4b_q06_`i'
	list cluster hhn idcode m4b_q05_`i' m4b_q06_`i' m4b_q07_`i' m4b_q07_`i'_check if m4b_q07_`i'!=m4b_q07_`i'_check  & !missing(m4b_q07_`i')
	drop m4b_q07_`i'_check
}

foreach var of varlist m4b_q08_*{
	di "`var'"
	list cluster hhn idcode `var' if `var'>52 & !missing(`var')
}




misstable summarize m4b*, all
tab m11_q07 if  m4b_q01_1==., nolabel

foreach i in 1 3 4 5 6 7 8 {
recode m4b_q0`i'_2 (.=.a) if m4b_q0`i'_1<.
recode m4b_q0`i'_3 (.=.a) if m4b_q0`i'_1<. | m4b_q0`i'_2<.
} 

foreach i in 11 {
recode m4b_q`i'_2 (.=.a) if m4b_q`i'_1<.
recode m4b_q`i'_3 (.=.a) if m4b_q`i'_1<. | m4b_q`i'_2<.
} 


*has everyone eligible to answer questions 4B?
list cluster hhn idcode m4a_q01 m4a_q02 m4a_q03 m4a_q04 m4a_q06 m4b_q01_1 m4b_q03_1 if missing(m4b_q01_1) & (m4a_q01==1 | m4a_q02==1 | m4a_q03==1| m4a_q04==1 | m4a_q06==1)

*string variables
foreach var of varlist m4b_q02_* {
	di "`var'"
	list cluster hhn idcode `var' if  `var'=="" & !missing(m4b_q01_1, m4b_q01_2, m4b_q04_3)
}

foreach var of varlist m4b_q12_1 m4b_q12_2 m4b_q12_3 {
	di "`var'"
	list cluster hhn idcode `var' if `var'=="" & !missing(m4b_q11_1, m4b_q11_2, m4b_q11_3)
}

list cluster hhn idcode m11_q07 if m4b_q01_1==. | m4b_q09==., nolabel

**********************
* MODULE 4C***********                                                                                 
**********************
list cluster hhn idcode m4c_q01_code m4b_q01_* m11_q07 if m4c_q01_code~=m4b_q01_1 & m4c_q01_code~=m4b_q01_2 & m4c_q01_code~=m4b_q01_3, nolabel
list cluster hhn idcode m4c_q01_code m4b_q01_* m11_q07 if m4c_q01_code==. & !missing(m4b_q01_1,m4b_q01_2,m4b_q01_3), nolabel

* skips 
foreach var of varlist m4c_q07 m4c_q08 m4c_q09_amnt m4c_q09_period m4c_q10 m4c_q11 m4c_q12 m4c_q13 m4c_q14 m4c_q15 m4c_q16 m4c_q17 {
	recode `var' (.=.b) if m4c_q06==1 
	list cluster hhn idcode m4c_q06 if m4c_q06==1  & !missing(`var')
	
}

foreach var of varlist  m4c_q07 m4c_q08 m4c_q09_amnt m4c_q09_period m4c_q10 m4c_q11 m4c_q12 m4c_q13 m4c_q14 m4c_q15 m4c_q16 m4c_q17 m4c_q18 m4c_q19 m4c_q20 m4c_q21 m4c_q22 m4c_q23 m4c_q24 m4c_q25 m4c_q26 m4c_q27 m4c_q28 {
	recode `var' (.=.b) if m4c_q06==3
	list cluster hhn idcode m4c_q06 if  m4c_q06==3 &!missing(`var')
	
}

foreach var of varlist m4c_q11 m4c_q12 {
	recode `var' (.=.b) if m4c_q10==2
	list cluster hhn idcode m4c_q10 `var' if m4c_q10==2 & !missing(`var')
}

recode m4c_q12 (.=.b) if  m4c_q11==2
list cluster hhn idcode m4c_q11 m4c_q12 if m4c_q11==2 & !missing(m4c_q12)


foreach var of varlist m4c_q14 m4c_q15 {
	recode `var' (.=.b) if m4c_q13==2
	list cluster hhn idcode m4c_q13 `var' if m4c_q13 ==2 & !missing(`var')
}

list cluster hhn idcode m4c_q14 if m4c_q14>2 & !missing(m4c_q14)


foreach var of varlist  m4c_q18 m4c_q19  {
	recode `var' (.=.b) if m4c_q17==1
	list cluster hhn idcode m4c_q17 `var' if m4c_q17==1 & !missing(`var')
	
}

foreach var of varlist m4c_q18 m4c_q19 m4c_q20 m4c_q21  {
	recode `var' (.=.b) if m4c_q17==2
	list cluster hhn idcode m4c_q17 `var' if m4c_q17==2 & !missing(`var')
}


list cluster hhn idcode m4c_q18 if m4c_q18>3 & !missing(m4c_q18)
list cluster hhn idcode m4c_q23 if m4c_q23>3 & !missing(m4c_q23)

foreach var of varlist  m4c_q24 m4c_q25  {
	recode `var' (.=.b) if m4c_q23==2 
	list cluster hhn idcode m4c_q23 `var' if (m4c_q23==2) & !missing(`var')
}

list cluster hhn idcode m4c_q25 if (m4c_q25==0 | m4c_q25>5) & !missing(m4c_q25)

foreach var of varlist  m4c_q24 m4c_q25 m4c_q26 m4c_q27  {
	recode `var' (.=.b) if m4c_q23==3
	list cluster hhn idcode m4c_q23 `var' if m4c_q23==3 & !missing(`var')
}
foreach var of varlist  m4c_q26 m4c_q27 {
	recode `var' (.=.b) if m4c_q25<.
	list cluster hhn idcode m4c_q25 `var' if m4c_q25<. & !missing(`var')
}

list cluster hhn idcode m4c_q28 if (m4c_q28==0 | m4c_q28>2) & !missing(m4c_q28)


foreach var of varlist m4c_q30_1 m4c_q30_2 m4c_q31 m4c_q32 m4c_q33 m4c_q34 m4c_q35 m4c_q36 {
	recode `var' (.=.b) if m4c_q29==2
	list cluster hhn idcode m4c_q29 `var' if m4c_q29==2 &!missing(`var')
}

foreach var of varlist m4c_q32 m4c_q33 m4c_q34 m4c_q35 m4c_q36 {
	recode `var' (.=.b) if m4c_q31==3
	list cluster hhn idcode m4c_q31 `var' if m4c_q31==3 &!missing(`var')
}


foreach var of varlist m4c_q33 m4c_q34 {
	recode `var' (.=.b) if m4c_q32==2
	list cluster hhn idcode m4c_q32 `var' if m4c_q32==2 &!missing(`var')
}
foreach var of varlist m4c_q33 m4c_q34 m4c_q35 m4c_q36 {
	recode `var' (.=.b) if m4c_q32==3
	list cluster hhn idcode m4c_q32 `var' if m4c_q32==3 &!missing(`var')
}

foreach var of varlist m4c_q35 m4c_q36 {
	recode `var' (.=.b) if m4c_q34<.
	list cluster hhn idcode m4c_q34 `var' if m4c_q34<. & !missing(`var')
}



misstable summarize m4c*, all

*string variables
list cluster hhn idcode m4c_q02 m4c_q02_other if m4c_q02==10 & m4c_q02_other==""
list cluster hhn idcode m4c_q04 m4c_q04_other if m4c_q04==9 & m4c_q04_other==""
list cluster hhn idcode m4c_q07 m4c_q07_other if m4c_q07==10 & m4c_q07_other==""
list cluster hhn idcode m4c_q12 m4c_q12_other if m4c_q12==9 & m4c_q12_other==""
list cluster hhn idcode m4c_q15 m4c_q15_other if m4c_q15==11 & m4c_q15_other==""
list cluster hhn idcode m4c_q19 m4c_q19_other if m4c_q19==9 & m4c_q19_other==""
list cluster hhn idcode m4c_q25 m4c_q25_other if m4c_q25==5 & m4c_q25_other==""
list cluster hhn idcode m4c_q27 m4c_q27_other if m4c_q27==5 & m4c_q27_other==""
list cluster hhn idcode m4c_q34 m4c_q34_other if m4c_q34==5 & m4c_q34_other==""
list cluster hhn idcode m4c_q36 m4c_q36_other if m4c_q36==5 & m4c_q36_other==""

*consistency
* M4c_27 amount should be equal or less than 4c_q9
list cluster hhn idcode m4c_q09_amnt m4c_q26 if m4c_q09_amnt < m4c_q26 & !missing(m4c_q09_amnt, m4c_q26)& m4c_q26~=92

**********************
* MODULE 5A***********                                                                                 
**********************
*filtering
*skips
recode m5a_q02 m5a_q02_occ_code (.=.b) if m5a_q01==1
list cluster hhn idcode m5a_q01 m5a_q02 m5a_q02_occ_code if m5a_q01==1 & !missing(m5a_q02,m5a_q02_occ_code)
recode m5a_q01_occ_code (.=.b) if m5a_q01==2
list cluster hhn idcode m5a_q01 m5a_q01_occ_code if m5a_q01==2 & !missing(m5a_q01_occ_code)


recode m5a_q02_occ_code (.=.b) if  m5a_q02==2
list cluster hhn idcode m5a_q02 m5a_q02_occ_code if m5a_q02==2 & !missing(m5a_q02_occ_code)

* select 1 if respondent answer module 4c?
list cluster hhn idcode m5a_q01 m4c_q01_code if m4c_q01_code<. & m5a_q01~=1, nolabel


* is occupation missing?
list cluster hhn idcode m5a_q01 m5a_q01_occ_code if m5a_q01==1 & m5a_q01_occ_code==.
list cluster hhn idcode m5a_q02 m5a_q02_occ_code if m5a_q02==1 & m5a_q02_occ_code==.

*is occupatoin code same as those in M4C_Q01_CODE?
list cluster hhn idcode m5a_q01 m5a_q01_occ_code m4c_q01_code if  (m4c_q01_code~=m5a_q01_occ_code) & m5a_q01==1, nolabel
*is occupation code same as those in M4A_Q20
list cluster hhn idcode m5a_q02 m5a_q02_occ_code m4a_q20 if (m5a_q02_occ_code~=m4a_q20) & m5a_q02==1, nolabel

*less than a year
list cluster hhn idcode m5a_q02 m4a_q19_y m4a_q19_mth m11_q03_v1m if m4a_q19_y>=2012 & !missing( m4a_q19_y) & m5a_q02~=1 & m5a_q02~=.b & (m4a_q19_mth>=m11_q03_v1m) & m4a_q19_mth~=99

misstable summarize m5a_q01 m5a_q01_occ_code m5a_q02 m5a_q02_occ_code if elegido==1, all

list cluster hhn idcode m5a_q01 m5a_q01_occ_code m5a_q02 m5a_q02_occ_code m4c_q01_code m4a_q20 m11_q07 if m5a_q01==. & elegido==1, nolabel
list cluster hhn idcode m5a_q01 m5a_q01_occ_code m5a_q02 m5a_q02_occ_code m4c_q01_code m4a_q20 m11_q07 if m5a_q01==. & elegido==1 &!missing(m4c_q01_code), nolabel
tab m5a_q01 m5a_q04, m nolab
tab m5a_q02 m5a_q04, m nolab
tab m5a_q02 m5a_q21, m nolab
tab m5a_q01 m5a_q21, m nolab

*recode skips
foreach var of varlist m5a_q04 m5a_q05_1 m5a_q05_2 m5a_q05_3 m5a_q05_4 m5a_q05_5 m5a_q05_6 m5a_q05_7 m5a_q06 m5a_q07 m5a_q08 m5a_q09_1 m5a_q09_2 m5a_q09_3 m5a_q09_4 m5a_q09_5 m5a_q09_6 m5a_q09_7 m5a_q10 m5a_q11 m5a_q12 m5a_q13 m5a_q14 m5a_q15 m5a_q16 m5a_q17 m5a_q18_1 m5a_q18_2 m5a_q18_3 m5a_q18_4 m5a_q18_5 m5a_q18_6 m5a_q19_1 m5a_q19_2 m5a_q19_3 m5a_q19_4 m5a_q19_5 m5a_q19_6 m5a_q20 {
	recode `var' (.=.b) if m5a_q02==2
	list cluster hhn idcode m5a_q01 m5a_q02 `var' if m5a_q02==2 &!missing(`var')
}

foreach var of varlist m5a_q05_1 m5a_q05_2 m5a_q05_3 m5a_q05_4 m5a_q05_5 m5a_q05_6 m5a_q05_7 m5a_q06 m5a_q07 {
	recode `var' (.=.b) if m5a_q04==2
	list cluster hhn idcode m5a_q04 `var' if m5a_q04==2 & !missing(`var')
}

foreach var of varlist m5a_q08 m5a_q09_1 m5a_q09_2 m5a_q09_3 m5a_q09_4 m5a_q09_5 m5a_q09_6 m5a_q09_7 m5a_q10{
	recode `var' (.=.b) if m5a_q07<.
	list cluster hhn idcode m5a_q07 `var' if m5a_q07<. & !missing(`var')
}

foreach var of varlist m5a_q09_1 m5a_q09_2 m5a_q09_3 m5a_q09_4 m5a_q09_5 m5a_q09_6 m5a_q09_7 m5a_q10{
	recode `var' (.=.b) if m5a_q08==2
	list cluster hhn idcode m5a_q08 `var' if m5a_q08==2 & !missing(`var')
}


foreach var of varlist m5a_q13 m5a_q14 {
	recode `var' (.=.b) if m5a_q12==2
	list cluster hhn idcode m5a_q12 `var' if m5a_q12==2 & !missing(`var')
}

foreach var of varlist m5a_q15 m5a_q16 m5a_q17{
	recode `var' (.=.b) if m5a_q14<.
	list cluster hhn idcode m5a_q14 `var' if m5a_q14<. & !missing(`var')
}

recode m5a_q17 (.=.b) if m5a_q16==2
list cluster hhn idcode m5a_q16 m5a_q17 if m5a_q16==2 & !missing(m5a_q17)

foreach var of varlist m5a_q21 m5a_q22_1 m5a_q22_2 m5a_q22_3 m5a_q22_4 m5a_q22_5 m5a_q22_6 m5a_q22_7 m5a_q23 m5a_q24 m5a_q25 m5a_q26 m5a_q27_1 m5a_q27_2 m5a_q27_3 m5a_q27_4 m5a_q27_5 m5a_q27_6 m5a_q28 {
	recode `var' (.=.b) if m5a_q20<.
	list cluster hhn idcode m5a_q20 `var' if m5a_q20<. & !missing(`var')
}


foreach var of varlist m5a_q22_1 m5a_q22_2 m5a_q22_3 m5a_q22_4 m5a_q22_5 m5a_q22_6 m5a_q22_7 m5a_q23 {
	recode `var' (.=.b) if  m5a_q21==2
	list cluster hhn idcode m5a_q21 `var' if m5a_q21==2 & !missing(`var')
	
}


recode m5a_q26 (.=.b) if m5a_q25==2
list cluster hhn idcode m5a_q25 m5a_q26 if m5a_q25==2 & !missing(m5a_q26)

misstable summarize m5a*, all

*others
 
list cluster hhn idcode m5a_q05_7 m5a_q05_7_other if m5a_q05_7==1 & m5a_q05_7_other==""
list cluster hhn idcode m5a_q09_7 m5a_q09_7_other if m5a_q09_7==1 & m5a_q09_7_other==""
list cluster hhn idcode m5a_q18_6 m5a_q18_6_other if m5a_q18_6==1 & m5a_q18_6_other==""
list cluster hhn idcode m5a_q19_6 m5a_q19_6_other if m5a_q19_6==1 & m5a_q19_6_other==""
list cluster hhn idcode m5a_q22_7 m5a_q22_7_other if m5a_q22_7==1 & m5a_q22_7_other==""
list cluster hhn idcode m5a_q27_6 m5a_q27_6_other if m5a_q27_6==1 & m5a_q27_6_other==""

misstable summarize m5a_*, all


**********************
* MODULE 5B***********                                                                                 
**********************
* who did not continue
list cluster hhn idcode m5a_q01 m5b_q01 m11_q07 if m5b_q01==. 
*is Q1 consistent with M5A
list cluster hhn idcode m5b_q01 m5a_q01 m5a_q02 if m5b_q01~=1 & (m5a_q01==1 | m5a_q02==1) & !missing(m5b_q01)
*has occupation code been filled out? 
list cluster hhn idcode  m5b_q01 m5b_q01_code if m5b_q01==1 & m5b_q01_code==., nolabel
*is occupation code consistent with M5A?
list cluster hhn idcode m5b_q01 m5b_q01_code m5a_q01_occ_code if m5b_q01==1 & m5b_q01_code~=m5a_q01_occ_code & !missing(m5b_q01_code,m5a_q01_occ_code), nolabel
list cluster hhn idcode m5b_q01 m5b_q01_code m5a_q02_occ_code if m5b_q01==1 & m5b_q01_code~=m5a_q02_occ_code & !missing(m5b_q01_code,m5a_q02_occ_code), nolabel

*Skips 
foreach var of varlist 	m5b_q02 m5b_q03 m5b_q04 m5b_q05 m5b_q06 m5b_q07 m5b_q08 ///
						m5b_q09 m5b_q10 m5b_q11_1 m5b_q11_2 m5b_q11_3  ///
						m5b_q12 m5b_q13 m5b_q14 m5b_q15_1 ///
						m5b_q16 m5b_q17 m5b_q18 m5b_q19 m5b_q20_* m5b_q21 m5b_q22_1 m5b_q22_2 ///
						m5b_q22_3 m5b_q22_4 m5b_q22_5 m5b_q22_6 m5b_q22_7 m5b_q22_8 ///
						m5b_q22_9 m5b_q23 m5b_q24 m5b_q25 m5b_q26 { 
	recode `var' (.=.b) if m5b_q01==2
	list cluster hhn idcode m5b_q01 `var' if m5b_q01==2 & !missing(`var')
}


recode m5b_q06 (.=.b) if m5b_q05==2
list cluster hhn idcode m5b_q05 m5b_q06 if m5b_q05==2 & !missing(m5b_q06)

foreach var of varlist  m5b_q19 m5b_q20_1 m5b_q20_2 m5b_q20_3 m5b_q20_4 m5b_q20_5 m5b_q20_6 m5b_q21 m5b_q22_1 m5b_q22_2 m5b_q22_3 m5b_q22_4 m5b_q22_5 m5b_q22_6 m5b_q22_7 m5b_q22_8 m5b_q22_9 {
	recode `var' (.=.b) if m5b_q18==2
	list cluster hhn idcode m5b_q18 `var' if m5b_q18==2 & !missing(`var')
}

foreach var of varlist m5b_q22_1 m5b_q22_2 m5b_q22_3 m5b_q22_4 m5b_q22_5 m5b_q22_6 m5b_q22_7 m5b_q22_8 m5b_q22_9 {
	recode `var' (.=.b) if m5b_q21==2
	list cluster hhn idcode m5b_q21 `var' if m5b_q21==2 & !missing(`var')
}


recode m5b_q29 (.=.b) if m5b_q28==1
list cluster hhn idcode m5b_q28 m5b_q29 if m5b_q28==1 &  !missing(m5b_q29)


recode m5b_q31 (.=.b) if m5b_q30==2
list cluster hhn idcode m5b_q30 m5b_q31 if m5b_q30==2 & !missing(m5b_q31)

foreach var of varlist m5b_q35 m5b_q36_1 m5b_q36_2 m5b_q36_3 m5b_q36_4 m5b_q36_5 {
	recode `var' (.=.b) if m5b_q34==2
	list cluster hhn idcode m5b_q34 `var' if m5b_q34==2 & !missing(`var')
}

foreach var of varlist m5b_q36_1 m5b_q36_2 m5b_q36_3 m5b_q36_4 m5b_q36_5 {
	recode `var' (.=.b) if m5b_q35==2
	list cluster hhn idcode m5b_q35 `var' if m5b_q35==2 & !missing(`var')
}


recode m5b_q11_2 m5b_q11_3 (.=.b) if m5b_q11_1!=. 

list cluster hhn idcode m5b_q10 m5b_q11_* m11_q07 if m5b_q11_1==. & m5b_q10!=.

list cluster hhn idcode m5b_q31 m5b_q32 if m5b_q31==. & m5b_q32!=.


misstable summarize m5b_*, all

* range

*others
list cluster hhn idcode m5b_q11_1 m5b_q11_2 m5b_q11_2 if m5b_q11_1==19 | m5b_q11_2==19 | m5b_q11_3==19
list cluster hhn idcode m5b_q22_9 m5b_q22_9_other if m5b_q22_9==1 & m5b_q22_9_other==""
list cluster hhn idcode m5b_q33_10 m5b_q33_10_other if m5b_q33_10==1 & m5b_q33_10_other==""
list cluster hhn idcode m5b_q36_5 m5b_q36_5_other if m5b_q36_5==1 & m5b_q36_5_other==""


**********************
* MODULE 6A***********                                                                                 
**********************
forvalues i=1(1)9{
di "m6a_q01_0`i'"
tab m6a_q01_0`i'
tab m6a_q01_0`i', m nolab
}
forvalues i=10(1)26{
di "m6a_q01_`i'"
tab m6a_q01_`i'
tab m6a_q01_`i', m nolab
}

foreach var of varlist m6a_q01_*{
recode `var' (.=.b) if m6a_q01a==2
list cluster hhn idcode `var' m11_q07 if m6a_q01a==.2 & !missing(`var') 
}

misstable summarize m6a_q01_*, all


**********************
* MODULE 6B***********                                                                                 
**********************
*skips
recode m6b_q02  (.=.b) if m6b_q01==2
list cluster hhn idcode m6b_q01 m6b_q02 if m6b_q01==2 & !missing(m6b_q02 )

recode m6b_q03 (.=.b) if m6b_q02==1 | m6b_q02==2
list cluster hhn idcode m6b_q01 m6b_q03 if (m6b_q02==1 | m6b_q02==2) & !missing(m6b_q03 )

recode m6b_q05 m6b_q06  (.=.b) if m6b_q04==2
list cluster hhn idcode m6b_q04 m6b_q05 m6b_q06  if m6b_q04==2 & (!missing(m6b_q05) | !missing(m6b_q06))

recode m6b_q06 m6b_q07  (.=.b) if m6b_q05==2
list cluster hhn idcode m6b_q05 m6b_q06 m6b_q07  if  m6b_q05==2 & (!missing(m6b_q06) | !missing(m6b_q07))

recode m6b_q07 (.=.b) if m6b_q05==1
list cluster hhn idcode m6b_q05 m6b_q07 if  m6b_q05==1 & !missing( m6b_q07)

list cluster hhn idcode m6b_q05-m6b_q07 m11_q07 if m6b_q07==. & m6b_q05!=.

misstable summarize m6b_*, all

**********************
* MODULE 7A*********** 	                                                                                
**********************

*skips

recode m7_q04  (.=.b) if m7_q03==1
list cluster hhn idcode m7_q03 m7_q04  if m7_q03==1 & !missing(m7_q04)

foreach var of varlist m7_q07 m7_q08 {
	recode `var'  (.=.b) if m7_q06==1
	list cluster hhn idcode m7_q06 `var'  if m7_q06==1 & !missing(`var')
}

recode m7_q08 (.=.b) if m7_q07==2
list cluster hhn idcode m7_q07 m7_q08  if m7_q07==2 & !missing(m7_q08)


foreach var of varlist m7_q10_*{
	recode `var' (.=.b) if m7_q09==2
	list cluster hhn idcode m7_q09 `var' if m7_q09==2 & !missing(`var')
}

recode m7_q12 (.=.b) if m7_q11==2
list cluster hhn idcode m7_q11 m7_q12 if m7_q11==2 & !missing(m7_q12)

recode m7_q13 (.=.b) if m7_q11==1
list cluster hhn idcode m7_q11 m7_q13 if m7_q11==1 & !missing(m7_q13)

list cluster hhn idcode m7_q11 m7_q13 if m7_q13==.

recode m7_q15 (.=.b)  if m7_q14==2
list cluster hhn idcode m7_q14 m7_q15 if m7_q14==2 & !missing(m7_q15)

recode m7_q16 (.=.b)  if m7_q14==1 
list cluster hhn idcode m7_q14 m7_q16 if m7_q14==1 & !missing(m7_q16)

recode m7_q25 (.=.b) (.=.b) if m7_q24==2
list cluster hhn idcode m7_q24 m7_q25 if m7_q24==2 & !missing(m7_q25)


misstable summarize m7_*, all

list cluster hhn idcode m7_q03 m7_q04 m11_q07 if m7_q04==. & m7_q03!=.
foreach var of varlist m7_q10_2-m7_q10_10 {
recode `var' (.=.a) if m7_q10_1!=.
} 
list cluster hhn idcode m7_q09 m7_q10_* m11_q07 if m7_q10_1==. & m7_q09!=.


*others
*list cluster hhn idcode m7_q01_5 m7_q01_5_other if m7_q01_5==1 & m7_q11_1_other==""

list cluster hhn idcode m7_q02 m7_q02_other if m7_q02==19 & m7_q02_other==""
list cluster hhn idcode m7_q05_11_a1 m7_q05_11_a2 if m7_q05_11_a1==1 & m7_q05_11_a2==""
list cluster hhn idcode m7_q21_14 m7_q21_14_other if m7_q21_14==1 & m7_q21_14_other==""
list cluster hhn idcode m7_q23_12 m7_q23_12_other if m7_q23_12==1 & m7_q23_12_other==""

* range

restore
*consistency/implementation
*gender for  mother
by cluster hhn, sort: egen idm=mean(m7_q12)
list cluster hhn idcode elegido m7_q12 m1a_q02 m1a_q03 m1a_q04 if idcode==idm & m1a_q02==1 

*gender for father 
by cluster hhn, sort: egen idf=mean(m7_q15)
list cluster hhn idcode elegido m7_q15 m1a_q02 m1a_q03 m1a_q04 if idcode==idf & m1a_q02==2

*if respondent is the household head, check if relationship is consistent
preserve
drop test 
gen hh=1 if elegido==1 & m1a_q03==1
by cluster hhn, sort: egen test=mean(hh)
keep if hh==1
*spouse
by cluster hhn, sort: egen ids=mean(m7_q08)
list cluster hhn idcode elegido m7_q08 m1a_q02 m1a_q03 m1a_q04 if idcode==ids & m1a_q03 ~=2 &!missing(m7_q08), nolabel

forvalues x=1/10 {
by cluster hhn, sort: egen idc_`x'=mean(m7_q10_`x')
list cluster hhn idcode elegido m7_q10_`x' m1a_q02 m1a_q03 m1a_q04 if idcode==idc_`x' & m1a_q03 ~=3 &!missing(m7_q10_`x')
drop idc_`x'
}

/*one case*/
* mother and father
list cluster hhn idcode elegido m7_q13 m1a_q02 m1a_q03 m1a_q04 if idm==idcode & m1a_q03 ~=5 & !missing(idm), nolabel
list cluster hhn idcode elegido m7_q16  m1a_q02 m1a_q03 m1a_q04 if idf==idcode & m1a_q03 ~=5 & !missing(idm), nolabel
restore


**********************
* MODULE 8************                                                                                 
**********************

misstable summarize m8* if elegido==1, all

foreach var of varlist m8_q02_* {
	recode `var' (.=.b) if m8_q01==2 & elegido==1
	list cluster hhn idcode m8_q01 `var' if m8_q01==2 & elegido==1 & !missing(`var')
}



**********************
* MODULE 9************                                                                                 
**********************

preserve 
keep if m11_q07>85
misstable summarize m9* if elegido==1, all

list cluster hhn idcode m9_sa_p2min m9_sa_p2sec m11_q07 if m9_sa_p2min==. & elegido==1
list cluster hhn idcode m9_sa_p3min m9_sa_p3sec m11_q07 if m9_sa_p2min==. & elegido==1
 
*range
list cluster hhn idcode m9_sa_p2* if (m9_sa_p2sec>60 & !missing(m9_sa_p2sec) )& elegido==1



**********************
* MODULE 10***********                                                                                 
**********************

misstable summarize m10* if elegido==1, all

foreach var of varlist m10_q02_* m10_q03 {
	recode `var' (.=.b) if m10_q01==2 & elegido==1
	list cluster hhn idcode m10_q01 `var' if m10_q01==2 & elegido==1 & !missing(`var')
}

***RESULT CODE***
 misstable summarize m11_q07, all 
 
 
